/*
 * The DAE2_combiner_bsm2.c is a C-file S-function level 2 for a speed-enhanced IAWQ AD Model No 1. 
 * In this model the traditional states of the ADM1 and ion states + Sh2
 * from the last iteration of the pHsolver and Sh2solver are combined to create the overall output
 * at time t for all variables rather than using values for the ion states and h2
 * that are one iteration old (h2 may still be considered old as it is based on the old pH
 * but this is really a question of the chicken and the egg).
 *
 * Copyright (2007):
 * Dr Ulf Jeppsson
 * Dept. Industrial Electrical Engineering and Automation (IEA)
 * Lund University, Sweden
 * http://www.iea.lth.se/ 
 *
 * Modified by Dr Xavier Flores-Alsina
 * Dept. Industrial Electrical Engineering and Automation (IEA)
 * Lund University, Sweden
 * http://www.iea.lth.se/ 
 * May 2014
 *
 */

#define S_FUNCTION_NAME DAE2_combiner_bsm2

#include "simstruc.h"

/*
 * mdlInitializeSizes - initialize the sizes array
 */
static void mdlInitializeSizes(SimStruct *S)
{
    ssSetNumContStates(    S, 0);   /* number of continuous states           */
    ssSetNumDiscStates(    S, 0);   /* number of discrete states             */
    ssSetNumInputs(        S, 59);  /* number of inputs                      */
    ssSetNumOutputs(       S, 51);  /* number of outputs                     */
    ssSetDirectFeedThrough(S, 1);   /* direct feedthrough flag               */
    ssSetNumSampleTimes(   S, 1);   /* number of sample times                */
    ssSetNumSFcnParams(    S, 0);   /* number of input arguments             */
    ssSetNumRWork(         S, 0);   /* number of real work vector elements   */
    ssSetNumIWork(         S, 0);   /* number of integer work vector elements*/
    ssSetNumPWork(         S, 0);   /* number of pointer work vector elements*/
}

/*
 * mdlInitializeSampleTimes - initialize the sample times array
 */
static void mdlInitializeSampleTimes(SimStruct *S)
{
    ssSetSampleTime(S, 0, CONTINUOUS_SAMPLE_TIME);
    ssSetOffsetTime(S, 0, 0.0);
}


/*
 * mdlInitializeConditions - initialize the states
 */
static void mdlInitializeConditions(double *x0, SimStruct *S)
{
}

/*
 * mdlOutputs - compute the outputs
 */

static void mdlOutputs(double *y, double *x, double *u, SimStruct *S, int tid)
{

int i;
 
for (i = 0; i < 32; i++) {
      y[i] = u[i];
  }    
 
  y[7] = u[58];   /* Sh2 */
   
  y[33] = -log10(u[51]);    /* pH */
  y[34] = u[51];            /* SH+ */  
  y[35] = u[35];  
  y[36] = u[36];  
  y[37] = u[37];  
  y[38] = u[38];  
  y[39] = 0.0;  
  y[40] = u[56];        /* SCO2 */
  y[41] = u[57];        /* SNH3 */
  y[42] = u[10] - u[57];       /* SNH4+ */
  y[43] = u[43];
  y[44] = u[44];
  y[45] = u[45];
  y[46] = u[46];
  y[47] = u[47];
  y[48] = u[48];
  y[49] = u[49];
  y[50] = u[50];
 
}

/*
 * mdlUpdate - perform action at major integration time step
 */

static void mdlUpdate(double *x, double *u, SimStruct *S, int tid)
{
}

/*
 * mdlDerivatives - compute the derivatives
 */
static void mdlDerivatives(double *dx, double *x, double *u, SimStruct *S, int tid)
{
}


/*
 * mdlTerminate - called when the simulation is terminated.
 */
static void mdlTerminate(SimStruct *S)
{
}

#ifdef	MATLAB_MEX_FILE    /* Is this file being compiled as a MEX-file? */
#include "simulink.c"      /* MEX-file interface mechanism */
#else
#include "cg_sfun.h"       /* Code generation registration function */
#endif

