/*
 * UQ_precipitation_DAEs model block 
 * Copyright: Xavier Flores-Alsina, Ulf Jeppsson, IEA, Lund University, Lund, Sweden
 *            Krist V. Gernaey, DTU, Denmark
 *            November 2013
 */

#define S_FUNCTION_NAME UQ_speciation_DAE

#include "simstruc.h"
#include "mex.h"
#include "lapack.h"
#include <math.h>

#define CHEM_INIT    ssGetArg(S,0)          /* initial values */
#define CHEM_PAR     ssGetArg(S,1)          /* chemical parameters */
#define ACTIVITY     ssGetArg(S,2)          /* activity parameters */

double *umain;
SimStruct *Smain;

/*
 * mdlInitializeSizes - initialize the sizes array
 */
static void mdlInitializeSizes(SimStruct *S)
{
    ssSetNumContStates(    S, 0);   /* number of continuous states           */
    ssSetNumDiscStates(    S, 20);   /* number of discrete states             */
    ssSetNumInputs(        S, 19);  /* number of inputs */
    ssSetNumOutputs(       S, 151);   /* number of outputs */
    ssSetDirectFeedThrough(S, 0);   /* direct feedthrough flag               */
    ssSetNumSampleTimes(   S, 1);   /* number of sample times                */
    ssSetNumSFcnParams(    S, 3);   /* number of input arguments             */
    ssSetNumRWork(         S, 0);   /* number of real work vector elements   */
    ssSetNumIWork(         S, 0);   /* number of integer work vector elements*/
    ssSetNumPWork(         S, 0);   /* number of pointer work vector elements*/
}



/*
 * mdlInitializeSampleTimes - initialize the sample times array
 */
static void mdlInitializeSampleTimes(SimStruct *S)
{
    ssSetSampleTime(S, 0, INHERITED_SAMPLE_TIME);
    ssSetOffsetTime(S, 0, 0.0);
}


/*
 * mdlInitializeConditions - initialize the states
 */
static void mdlInitializeConditions(double *x0, SimStruct *S)
{
int i;

for (i = 0; i < 20; i++) {
   x0[i] = mxGetPr(CHEM_INIT)[i];
  }
}



/*
 * mdlOutputs - compute the outputs
 */
static void mdlOutputs(double *y, double *x, double *u, SimStruct *S, int tid)
{
double KT_AlAc2,KT_AlOH2,KT_AlOH3_aq,KT_AlOH4,KT_AlS2O8,KT_Al2OH8,KT_Al2OH2Ac,KT_AlOH2CO3,KT_Al2PO4,KT_Al3OH4,KT_AlAc,KT_AlBu,KT_AlCl,KT_AlHPO4,KT_AlOH; 
double KT_AlOHAc,KT_AlPr,KT_AlSO4,KT_CaN2H6,KT_CaAc,KT_CaBu,KT_CaCl,KT_CaCO3_aq,KT_CaH2PO4,KT_CaHCO3,KT_CaHPO4_aq,KT_CaNH3,KT_CaOH,KT_CaPO4,KT_CaPr,KT_CaSO4_aq,KT_CaVa,KT_FeAc2,KT_FeAc3_aq,KT_FeN2H6,KT_FeN3H9,KT_FeN4H12,KT_FeOH2_aq,KT_FeOH2;
double KT_FeOH3,KT_FeOH3_aq,KT_FeOH4,KT_FeS2O8,KT_Fe2O2H2,KT_Fe3O4H4,KT_FeAc,KT_FeAc_2,KT_FeBu_2,KT_FeCl,KT_FeCl_2,KT_FeH2PO4,KT_FeH2PO4_2,KT_FeHCO3,KT_FeHPO4_aq,KT_FeHPO4,KT_FeHS,KT_FeNH3,KT_FeOH,KT_FeOH_2,KT_FePr,KT_FeSO4_aq,KT_FeSO4,KT_FeVa_2,KT_H2CO3_aq,KT_H2PO4,KT_H2S_aq,KT_H3PO4,KT_HAc_aq,KT_HBu_aq,KT_HCO3,KT_HPO4,KT_HPr_aq,KT_HSO4,KT_HVa_aq,KT_K2HPO4_aq,KT_K2PO4,KT_KAc_aq,KT_KCl_aq,KT_KH2PO4_aq,KT_KHPO4,KT_KOH_aq,KT_KPO4,KT_KSO4; 
double KT_MgN2H6,KT_Mg2CO3,KT_MgAc,KT_MgBu,KT_MgCl,KT_MgCO3_aq,KT_MgHCO3,KT_MgHPO4_aq,KT_MgOH,KT_MgPO4,KT_MgPr,KT_MgSO4_aq,KT_Na2HPO4_aq,KT_Na2PO4,KT_NaAc_aq,KT_NaCl_aq,KT_NaCO3,KT_NaH2PO4_aq,KT_NaHCO3_aq,KT_NaHPO4,KT_NaOH_aq,KT_NaPO4,KT_NaSO4,KT_NH3_aq,KT_NH4SO4,KT_H2O,KT_S,KT_CO2;

double S_act_H, S_act_Na, S_act_K, S_act_NH4,S_act_Cl,S_act_Ac,S_act_Pr, S_act_Ca, S_act_Mg, S_act_CO3, S_act_SO4,S_act_PO4, S_act_Al, S_act_Fe2, S_act_Fe3, S_act_HS, S_act_Bu, S_act_Va, mu, gama;    
double gama2, gama3, gama4, gama5;

double xtemp[151];
int i;

KT_AlAc2 = mxGetPr(CHEM_PAR)[0]; 
KT_AlOH2 = mxGetPr(CHEM_PAR)[1];
KT_AlOH3_aq = mxGetPr(CHEM_PAR)[2];
KT_AlOH4 = mxGetPr(CHEM_PAR)[3];
KT_AlS2O8 = mxGetPr(CHEM_PAR)[4];
KT_Al2OH8 = mxGetPr(CHEM_PAR)[5];
KT_Al2OH2Ac = mxGetPr(CHEM_PAR)[6];
KT_AlOH2CO3 = mxGetPr(CHEM_PAR)[7];
KT_Al2PO4 = mxGetPr(CHEM_PAR)[8];
KT_Al3OH4 = mxGetPr(CHEM_PAR)[9];
KT_AlBu = mxGetPr(CHEM_PAR)[10];
KT_AlAc = mxGetPr(CHEM_PAR)[11];
KT_AlCl = mxGetPr(CHEM_PAR)[12];
KT_AlHPO4 = mxGetPr(CHEM_PAR)[13];
KT_AlOH = mxGetPr(CHEM_PAR)[14];
KT_AlOHAc = mxGetPr(CHEM_PAR)[15];
KT_AlPr = mxGetPr(CHEM_PAR)[16];
KT_AlSO4 = mxGetPr(CHEM_PAR)[17];
KT_CaN2H6 = mxGetPr(CHEM_PAR)[18];
KT_CaAc = mxGetPr(CHEM_PAR)[19];
KT_CaBu = mxGetPr(CHEM_PAR)[20];
KT_CaCl = mxGetPr(CHEM_PAR)[21];
KT_CaH2PO4 = mxGetPr(CHEM_PAR)[22];
KT_CaCO3_aq = mxGetPr(CHEM_PAR)[23];
KT_CaHCO3 = mxGetPr(CHEM_PAR)[24];
KT_CaHPO4_aq = mxGetPr(CHEM_PAR)[25];
KT_CaNH3 = mxGetPr(CHEM_PAR)[26];
KT_CaOH = mxGetPr(CHEM_PAR)[27];
KT_CaPO4 = mxGetPr(CHEM_PAR)[28];
KT_CaPr = mxGetPr(CHEM_PAR)[29];
KT_CaSO4_aq = mxGetPr(CHEM_PAR)[30];
KT_CaVa = mxGetPr(CHEM_PAR)[31];
KT_FeAc2 = mxGetPr(CHEM_PAR)[32];
KT_FeAc3_aq = mxGetPr(CHEM_PAR)[33];
KT_FeN2H6 = mxGetPr(CHEM_PAR)[34];
KT_FeN3H9 = mxGetPr(CHEM_PAR)[35];
KT_FeN4H12 = mxGetPr(CHEM_PAR)[36];
KT_FeOH2_aq = mxGetPr(CHEM_PAR)[37];
KT_FeOH2 = mxGetPr(CHEM_PAR)[38];
KT_FeOH3 = mxGetPr(CHEM_PAR)[39];
KT_FeOH3_aq = mxGetPr(CHEM_PAR)[40];
KT_FeOH4= mxGetPr(CHEM_PAR)[41];
KT_FeS2O8= mxGetPr(CHEM_PAR)[42];
KT_Fe2O2H2= mxGetPr(CHEM_PAR)[43];
KT_Fe3O4H4= mxGetPr(CHEM_PAR)[44];
KT_FeAc= mxGetPr(CHEM_PAR)[45];
KT_FeAc_2= mxGetPr(CHEM_PAR)[46];
KT_FeBu_2 = mxGetPr(CHEM_PAR)[47];
KT_FeCl= mxGetPr(CHEM_PAR)[48];
KT_FeCl_2= mxGetPr(CHEM_PAR)[49];
KT_FeH2PO4= mxGetPr(CHEM_PAR)[50];
KT_FeH2PO4_2= mxGetPr(CHEM_PAR)[51];
KT_FeHCO3= mxGetPr(CHEM_PAR)[52];
KT_FeHPO4_aq = mxGetPr(CHEM_PAR)[53];
KT_FeHPO4 = mxGetPr(CHEM_PAR)[54];
KT_FeHS = mxGetPr(CHEM_PAR)[55];
KT_FeNH3 = mxGetPr(CHEM_PAR)[56];
KT_FeOH = mxGetPr(CHEM_PAR)[57];
KT_FeOH_2 = mxGetPr(CHEM_PAR)[58];
KT_FePr = mxGetPr(CHEM_PAR)[59];
KT_FeSO4_aq = mxGetPr(CHEM_PAR)[60];
KT_FeSO4 = mxGetPr(CHEM_PAR)[61];
KT_FeVa_2 = mxGetPr(CHEM_PAR)[62];
KT_H2CO3_aq = mxGetPr(CHEM_PAR)[63];
KT_H2PO4 = mxGetPr(CHEM_PAR)[64];
KT_H2S_aq = mxGetPr(CHEM_PAR)[65];
KT_H3PO4 = mxGetPr(CHEM_PAR)[66];
KT_HAc_aq = mxGetPr(CHEM_PAR)[67];
KT_HBu_aq = mxGetPr(CHEM_PAR)[68];
KT_HCO3 = mxGetPr(CHEM_PAR)[69];
KT_HPO4 = mxGetPr(CHEM_PAR)[70];
KT_HPr_aq = mxGetPr(CHEM_PAR)[71];
KT_HSO4 = mxGetPr(CHEM_PAR)[72];
KT_HVa_aq = mxGetPr(CHEM_PAR)[73];
KT_K2HPO4_aq =mxGetPr(CHEM_PAR)[74];
KT_K2PO4 = mxGetPr(CHEM_PAR)[75];
KT_KAc_aq = mxGetPr(CHEM_PAR)[76];
KT_KCl_aq = mxGetPr(CHEM_PAR)[77];
KT_KH2PO4_aq = mxGetPr(CHEM_PAR)[78];
KT_KHPO4 = mxGetPr(CHEM_PAR)[79];
KT_KOH_aq = mxGetPr(CHEM_PAR)[80];
KT_KPO4 = mxGetPr(CHEM_PAR)[81];
KT_KSO4 = mxGetPr(CHEM_PAR)[82];
KT_MgN2H6 = mxGetPr(CHEM_PAR)[83];
KT_Mg2CO3 = mxGetPr(CHEM_PAR)[84];
KT_MgAc = mxGetPr(CHEM_PAR)[85];
KT_MgBu = mxGetPr(CHEM_PAR)[86];
KT_MgCl = mxGetPr(CHEM_PAR)[87];
KT_MgCO3_aq = mxGetPr(CHEM_PAR)[88];
KT_MgHCO3 = mxGetPr(CHEM_PAR)[89];
KT_MgHPO4_aq =mxGetPr(CHEM_PAR)[90];
KT_MgOH = mxGetPr(CHEM_PAR)[91];
KT_MgPO4 = mxGetPr(CHEM_PAR)[92];
KT_MgPr = mxGetPr(CHEM_PAR)[93];
KT_MgSO4_aq =mxGetPr(CHEM_PAR)[94];
KT_Na2HPO4_aq =mxGetPr(CHEM_PAR)[95];
KT_Na2PO4 = mxGetPr(CHEM_PAR)[96];
KT_NaAc_aq = mxGetPr(CHEM_PAR)[97];
KT_NaCl_aq = mxGetPr(CHEM_PAR)[98];
KT_NaCO3 = mxGetPr(CHEM_PAR)[99];
KT_NaH2PO4_aq =mxGetPr(CHEM_PAR)[100];
KT_NaHCO3_aq = mxGetPr(CHEM_PAR)[101];
KT_NaHPO4 = mxGetPr(CHEM_PAR)[102];
KT_NaOH_aq =mxGetPr(CHEM_PAR)[103];
KT_NaPO4 =mxGetPr(CHEM_PAR)[104];
KT_NaSO4 =mxGetPr(CHEM_PAR)[105];
KT_NH3_aq = mxGetPr(CHEM_PAR)[106];
KT_NH4SO4 = mxGetPr(CHEM_PAR)[107];
KT_H2O = mxGetPr(CHEM_PAR)[108];
KT_S =mxGetPr(CHEM_PAR)[109];
KT_CO2 = mxGetPr(CHEM_PAR)[110];

gama2 = pow(gama,4);     // For divalent ions
gama3 = pow(gama,9);     // For trivalent ions
gama4 = pow(gama,16);    // 4 times charged ions
gama5 = pow(gama,25);    // 5 times charged ions  


for (i = 0; i < 20; i++) {
   if (x[i] < 1e-15)
     xtemp[i] = 0.0;
   else
     xtemp[i] = x[i];
}

S_act_H = xtemp[0];      // Activity of hydrogen ion
S_act_Na = xtemp[1];     // Activity of sodium ion
S_act_K = xtemp[2];      // Activity of potassium ion
S_act_NH4 = xtemp[3];    // Activity of ammonium ion
S_act_Cl = xtemp[4];     // Activity of chloride ion
S_act_Ac = xtemp[5];     // Activity of acetate ion
S_act_Pr = xtemp[6];     // Activity of proppionate ion
S_act_Ca = xtemp[7];     // Activity of calcium ion
S_act_Mg = xtemp[8];     // Activity of magnesium ion
S_act_CO3 = xtemp[9];    // Activity of carbonate ion
S_act_SO4 = xtemp[10];   // Activity of sulfate ion 
S_act_PO4 = xtemp[11];   // Activity of phosphate ion
S_act_Al = xtemp[12];
S_act_Fe2 = xtemp[13];
S_act_Fe3 = xtemp[14];
S_act_HS = xtemp[15];
S_act_Bu = xtemp[16];
S_act_Va = xtemp[17];
mu = xtemp[18];          // Ionic strength of the solution
gama = xtemp[19];        // Activity coefficient

// output activities

y[0]= S_act_H;
y[1]= S_act_Na;
y[2]= S_act_K ;
y[3]= S_act_NH4;
y[4]= S_act_Cl;
y[5]= S_act_Ac;
y[6]= S_act_Pr;
y[7]= S_act_Ca;
y[8]= S_act_Mg;
y[9]= S_act_CO3;
y[10]= S_act_SO4;
y[11]= S_act_PO4;
y[12]= S_act_Al;
y[13]= S_act_Fe2;
y[14]= S_act_Fe3;
y[15]= S_act_HS;
y[16]= S_act_Bu;
y[17]= S_act_Va;
y[18]= mu;
y[19]= gama;

// output concentrations

y[20]= S_act_H/gama;         // H
y[21]= S_act_Na/gama;        // Na
y[22]= S_act_K /gama;        // K
y[23]= S_act_NH4/gama;       // NH4
y[24]= S_act_Cl/gama;        // Cl
y[25]= S_act_Ac/gama;        // Ac
y[26]= S_act_Pr/gama;        // Prop    
y[27]= S_act_Ca/pow(gama,4); // Ca
y[28]= S_act_Mg/pow(gama,4); // Mg
y[29]= S_act_CO3/pow(gama,4);// CO3-2
y[30]= S_act_SO4/pow(gama,4);// SO4-2
y[31]= S_act_PO4/pow(gama,9);//PO4-3 
y[32]= S_act_Al/pow(gama,9); //Al
y[33]= S_act_Fe2/pow(gama,4);//Fe+2 
y[34]= S_act_Fe3/pow(gama,9);//Fe+3
y[35]= S_act_HS/gama;        //Fe+3  
y[36]= S_act_Bu/gama;        //Bu
y[37]= S_act_Va/gama;        //Va

// Ph values
y[38]= -log10(S_act_H);         // based on activity
y[39] =-log10(S_act_H/gama);    // based on concentration

// species composition

y[40] = (KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al)/gama;
y[41] = (KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al)/gama;
y[42] =  KT_AlOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Al;
y[43] = (KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al)/gama;
y[44] = (KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al)/gama;
y[45] = (KT_Al2OH8*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al))/gama4;
y[46] = (KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al))/gama3;;
y[47] = (KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al))/gama2;
y[48] = (KT_Al2PO4*S_act_PO4*(S_act_Al*S_act_Al))/gama3;
y[49] = (KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al))/gama5;
y[50] = (KT_AlAc*S_act_Ac*S_act_Al)/gama2;
y[51] =(KT_AlBu*S_act_Al*S_act_Bu)/gama2;
y[52] =(KT_AlCl*S_act_Al*S_act_Cl)/gama2;
y[53] = (KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al)/gama;
y[54] = (KT_AlOH*S_act_Al)/(S_act_H*gama2);
y[55] = (KT_AlOHAc*S_act_Ac*S_act_Al)/(S_act_H*gama);
y[56] = (KT_AlPr*S_act_Al*S_act_Pr)/gama2;
y[57] = (KT_AlSO4*S_act_SO4*S_act_Al)/gama;
y[58] = (KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca)/gama2;
y[59] = (KT_CaAc*S_act_Ac*S_act_Ca)/gama;
y[60] = (KT_CaBu*S_act_Ca*S_act_Bu)/gama;
y[61] = (KT_CaCl*S_act_Ca*S_act_Cl)/gama;
y[62] = KT_CaCO3_aq*S_act_CO3*S_act_Ca;
y[63] = (KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca)/gama;
y[64] = (KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca)/gama;
y[65] = KT_CaHPO4_aq*S_act_H*S_act_PO4*S_act_Ca;
y[66] = (KT_CaNH3*S_act_NH4*S_act_Ca)/(S_act_H*gama2);
y[67] = (KT_CaOH*S_act_Ca)/(S_act_H*gama);
y[68] = (KT_CaPO4*S_act_PO4*S_act_Ca)/gama;
y[69] = (KT_CaPr*S_act_Ca*S_act_Pr)/gama;
y[70] = KT_CaSO4_aq*S_act_Ca*S_act_SO4;
y[71] = (KT_CaVa*S_act_Ca*S_act_Va)/gama;
y[72] = (KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3)/gama;
y[73] = KT_FeAc3_aq*(S_act_Ac*S_act_Ac*S_act_Ac)*S_act_Fe3;
y[74] = (KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2;
y[75] = (KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2;
y[76] = (KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2;
y[77] = KT_FeOH2_aq*1.0/(S_act_H*S_act_H)*S_act_Fe2;
y[78] = (KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3)/gama;
y[79] = (KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2)/gama;
y[80] = KT_FeOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe3;
y[81] = (KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3)/gama;
y[82] = (KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3)/gama;
y[83] = (KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3))/gama4;
y[84] = (KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3))/gama5;
y[85] = (KT_FeAc*S_act_Ac*S_act_Fe2)/gama;
y[86] = (KT_FeAc_2*S_act_Ac*S_act_Fe3)/gama2;
y[87] = (KT_FeBu_2*S_act_Fe3*S_act_Bu)/gama2;
y[88] = (KT_FeCl*S_act_Fe2*S_act_Cl)/gama;
y[89] = (KT_FeCl_2*S_act_Fe3*S_act_Cl)/gama2;
y[90] =(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2)/gama;
y[91] = (KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe3)/gama2;
y[92] = (KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2)/gama;
y[93] = KT_FeHPO4_aq*S_act_H*S_act_PO4*S_act_Fe2;
y[94] = (KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3)/gama;
y[95] = (KT_FeHS*S_act_HS*S_act_Fe2)/gama;
y[96] = (KT_FeNH3*S_act_NH4*S_act_Fe2)/(S_act_H*gama2);
y[97] = (KT_FeOH*S_act_Fe2)/(S_act_H*gama);
y[98] = (KT_FeOH_2*S_act_Fe3)/(S_act_H*gama2);
y[99] = (KT_FePr*S_act_Fe3*S_act_Pr)/gama2;
y[100] = KT_FeSO4_aq*S_act_SO4*S_act_Fe2;
y[101] = (KT_FeSO4*S_act_SO4*S_act_Fe3)/gama;
y[102] = (KT_FeVa_2*S_act_Fe3*S_act_Va)/gama2;
y[103] = KT_H2CO3_aq*(S_act_H*S_act_H)*S_act_CO3;
y[104] = (KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama;
y[105] = KT_H2S_aq*S_act_H*S_act_HS;
y[106] = KT_H3PO4*(S_act_H*S_act_H*S_act_H)*S_act_PO4;
y[107] = KT_HAc_aq*S_act_H*S_act_Ac;
y[108] = KT_HBu_aq*S_act_H*S_act_Bu;
y[109] = (KT_HCO3*S_act_H*S_act_CO3)/gama;
y[110] = (KT_HPO4*S_act_H*S_act_PO4)/gama2;
y[111] = KT_HPr_aq*S_act_H*S_act_Pr;
y[112] = (KT_HSO4*S_act_H*S_act_SO4)/gama;
y[113] = KT_HVa_aq*S_act_H*S_act_Va;
y[114] = KT_K2HPO4_aq*S_act_H*(S_act_K*S_act_K)*S_act_PO4;
y[115] = (KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4)/gama;
y[116] = KT_KAc_aq*S_act_K*S_act_Ac;
y[117] = KT_KCl_aq*S_act_K*S_act_Cl;
y[118] = KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_K*S_act_PO4;
y[119] = (KT_KHPO4*S_act_H*S_act_K*S_act_PO4)/gama;
y[120] = (KT_KOH_aq*S_act_K)/S_act_H;
y[121] = (KT_KPO4*S_act_K*S_act_PO4)/gama2;
y[122] = (KT_KSO4*S_act_K*S_act_SO4)/gama;
y[123] = (KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg)/gama2;
y[124] = (KT_Mg2CO3*S_act_CO3*(S_act_Mg*S_act_Mg))/gama2;
y[125] = (KT_MgAc*S_act_Ac*S_act_Mg)/gama;
y[126] = (KT_MgBu*S_act_Mg*S_act_Bu)/gama;
y[127] = (KT_MgCl*S_act_Cl*S_act_Mg)/gama;
y[128] = KT_MgCO3_aq*S_act_CO3*S_act_Mg;
y[129] = (KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg)/gama;
y[130] = KT_MgHPO4_aq*S_act_H*S_act_PO4*S_act_Mg;
y[131] = (KT_MgOH*S_act_Mg)/(S_act_H*gama);
y[132] = (KT_MgPO4*S_act_PO4*S_act_Mg)/gama;
y[133] = (KT_MgPr*S_act_Mg*S_act_Pr)/gama;
y[134] = KT_MgSO4_aq*S_act_SO4*S_act_Mg;
y[135] = KT_Na2HPO4_aq*S_act_H*S_act_PO4*(S_act_Na*S_act_Na);
y[136] =(KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na))/gama;
y[137] = KT_NaAc_aq*S_act_Ac*S_act_Na;
y[138] = KT_NaCl_aq*S_act_Cl*S_act_Na;
y[139] = (KT_NaCO3*S_act_CO3*S_act_Na)/gama;
y[140] = KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4*S_act_Na;
y[141] = KT_NaHCO3_aq*S_act_H*S_act_CO3*S_act_Na;
y[142] = (KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na)/gama;
y[143] = (KT_NaOH_aq*S_act_Na)/S_act_H;
y[144] = (KT_NaPO4*S_act_PO4*S_act_Na)/gama2;
y[145] = (KT_NaSO4*S_act_SO4*S_act_Na)/gama;
y[146] = (KT_NH3_aq*S_act_NH4)/S_act_H;
y[147] = (KT_NH4SO4*S_act_NH4*S_act_SO4)/gama;
y[148] = KT_H2O/(S_act_H*gama);
y[149] = (KT_S*S_act_HS)/(S_act_H*gama2);
y[150] = KT_CO2*(S_act_H*S_act_H)*S_act_CO3;


}

void MatDiv(int dim, double *A, double *B, double *Bout)//nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]
{

    mwSignedIndex m,n,p;     /* matrix dimensions */ 
    mwSignedIndex *iPivot;   /* inputs to DGESV */
    mxArray *mxPivot;
    mwSignedIndex info, dims[2];
	unsigned int i;
	double *Awork=malloc(dim*dim*sizeof(*Awork));	//not allowed to use new

  
    /* dimensions of input matrices */
    m = (mwSignedIndex)dim;  
    p = (mwSignedIndex)dim;
    n = (mwSignedIndex)1;

    /* DGESV works in-place, so we copy the inputs first. */
	for (i=0;i<dim;i++) Bout[i]=B[i];
	for (i=0;i<(dim*dim);i++) Awork[i]=A[i];
  
    /* Create pivot for DGESV */
    dims[0] = m;
    dims[1] = p;
    mxPivot = mxCreateNumericArray(2, dims, mxINT32_CLASS, mxREAL);
    iPivot = (mwSignedIndex*)mxGetData(mxPivot);
  
    /* Call LAPACK */
    dgesv(&m,&n,Awork,&m,iPivot,Bout,&p,&info);
    /* Bout now holds X */
	//todo recover status from info

    mxDestroyArray(mxPivot);
	free(Awork);
}



bool FunEv(const double x[], unsigned int neq, double Equ[])
{
	SimStruct *S;
    double *u;
    
double KT_AlAc2,KT_AlOH2,KT_AlOH3_aq,KT_AlOH4,KT_AlS2O8,KT_Al2OH8,KT_Al2OH2Ac,KT_AlOH2CO3,KT_Al2PO4,KT_Al3OH4,KT_AlAc,KT_AlBu,KT_AlCl,KT_AlHPO4,KT_AlOH; 
double KT_AlOHAc,KT_AlPr,KT_AlSO4,KT_CaN2H6,KT_CaAc,KT_CaBu,KT_CaCl,KT_CaCO3_aq,KT_CaH2PO4,KT_CaHCO3,KT_CaHPO4_aq,KT_CaNH3,KT_CaOH,KT_CaPO4,KT_CaPr,KT_CaSO4_aq,KT_CaVa,KT_FeAc2,KT_FeAc3_aq,KT_FeN2H6,KT_FeN3H9,KT_FeN4H12,KT_FeOH2_aq,KT_FeOH2;
double KT_FeOH3,KT_FeOH3_aq,KT_FeOH4,KT_FeS2O8,KT_Fe2O2H2,KT_Fe3O4H4,KT_FeAc,KT_FeAc_2,KT_FeBu_2,KT_FeCl,KT_FeCl_2,KT_FeH2PO4,KT_FeH2PO4_2,KT_FeHCO3,KT_FeHPO4_aq,KT_FeHPO4,KT_FeHS,KT_FeNH3,KT_FeOH,KT_FeOH_2,KT_FePr,KT_FeSO4_aq,KT_FeSO4,KT_FeVa_2,KT_H2CO3_aq,KT_H2PO4,KT_H2S_aq,KT_H3PO4,KT_HAc_aq,KT_HBu_aq,KT_HCO3,KT_HPO4,KT_HPr_aq,KT_HSO4,KT_HVa_aq,KT_K2HPO4_aq,KT_K2PO4,KT_KAc_aq,KT_KCl_aq,KT_KH2PO4_aq,KT_KHPO4,KT_KOH_aq,KT_KPO4,KT_KSO4; 
double KT_MgN2H6,KT_Mg2CO3,KT_MgAc,KT_MgBu,KT_MgCl,KT_MgCO3_aq,KT_MgHCO3,KT_MgHPO4_aq,KT_MgOH,KT_MgPO4,KT_MgPr,KT_MgSO4_aq,KT_Na2HPO4_aq,KT_Na2PO4,KT_NaAc_aq,KT_NaCl_aq,KT_NaCO3,KT_NaH2PO4_aq,KT_NaHCO3_aq,KT_NaHPO4,KT_NaOH_aq,KT_NaPO4,KT_NaSO4,KT_NH3_aq,KT_NH4SO4,KT_H2O,KT_S,KT_CO2;

double d, eps, A;

double S_act_H, S_act_Na, S_act_K, S_act_NH4,S_act_Cl,S_act_Ac,S_act_Pr, S_act_Ca, S_act_Mg, S_act_CO3, S_act_SO4,S_act_PO4, S_act_Al, S_act_Fe2, S_act_Fe3, S_act_HS, S_act_Bu, S_act_Va, mu, gama;
double Tot_H,Tot_Na, Tot_K, Tot_NH4, Tot_Cl, Tot_Ac, Tot_Pr, Tot_Ca, Tot_Mg, Tot_CO3, Tot_SO4, Tot_PO4, Tot_Al, Tot_Fe2, Tot_Fe3, Tot_HS, Tot_Bu, Tot_Va, Temp_C, Temp_K;
double gama2, gama3, gama4, gama5;
        
	S=Smain;
    u=umain;

KT_AlAc2 = mxGetPr(CHEM_PAR)[0]; 
KT_AlOH2 = mxGetPr(CHEM_PAR)[1];
KT_AlOH3_aq = mxGetPr(CHEM_PAR)[2];
KT_AlOH4 = mxGetPr(CHEM_PAR)[3];
KT_AlS2O8 = mxGetPr(CHEM_PAR)[4];
KT_Al2OH8 = mxGetPr(CHEM_PAR)[5];
KT_Al2OH2Ac = mxGetPr(CHEM_PAR)[6];
KT_AlOH2CO3 = mxGetPr(CHEM_PAR)[7];
KT_Al2PO4 = mxGetPr(CHEM_PAR)[8];
KT_Al3OH4 = mxGetPr(CHEM_PAR)[9];
KT_AlBu = mxGetPr(CHEM_PAR)[10];
KT_AlAc = mxGetPr(CHEM_PAR)[11];
KT_AlCl = mxGetPr(CHEM_PAR)[12];
KT_AlHPO4 = mxGetPr(CHEM_PAR)[13];
KT_AlOH = mxGetPr(CHEM_PAR)[14];
KT_AlOHAc = mxGetPr(CHEM_PAR)[15];
KT_AlPr = mxGetPr(CHEM_PAR)[16];
KT_AlSO4 = mxGetPr(CHEM_PAR)[17];
KT_CaN2H6 = mxGetPr(CHEM_PAR)[18];
KT_CaAc = mxGetPr(CHEM_PAR)[19];
KT_CaBu = mxGetPr(CHEM_PAR)[20];
KT_CaCl = mxGetPr(CHEM_PAR)[21];
KT_CaH2PO4 = mxGetPr(CHEM_PAR)[22];
KT_CaCO3_aq = mxGetPr(CHEM_PAR)[23];
KT_CaHCO3 = mxGetPr(CHEM_PAR)[24];
KT_CaHPO4_aq = mxGetPr(CHEM_PAR)[25];
KT_CaNH3 = mxGetPr(CHEM_PAR)[26];
KT_CaOH = mxGetPr(CHEM_PAR)[27];
KT_CaPO4 = mxGetPr(CHEM_PAR)[28];
KT_CaPr = mxGetPr(CHEM_PAR)[29];
KT_CaSO4_aq = mxGetPr(CHEM_PAR)[30];
KT_CaVa = mxGetPr(CHEM_PAR)[31];
KT_FeAc2 = mxGetPr(CHEM_PAR)[32];
KT_FeAc3_aq = mxGetPr(CHEM_PAR)[33];
KT_FeN2H6 = mxGetPr(CHEM_PAR)[34];
KT_FeN3H9 = mxGetPr(CHEM_PAR)[35];
KT_FeN4H12 = mxGetPr(CHEM_PAR)[36];
KT_FeOH2_aq = mxGetPr(CHEM_PAR)[37];
KT_FeOH2 = mxGetPr(CHEM_PAR)[38];
KT_FeOH3 = mxGetPr(CHEM_PAR)[39];
KT_FeOH3_aq = mxGetPr(CHEM_PAR)[40];
KT_FeOH4= mxGetPr(CHEM_PAR)[41];
KT_FeS2O8= mxGetPr(CHEM_PAR)[42];
KT_Fe2O2H2= mxGetPr(CHEM_PAR)[43];
KT_Fe3O4H4= mxGetPr(CHEM_PAR)[44];
KT_FeAc= mxGetPr(CHEM_PAR)[45];
KT_FeAc_2= mxGetPr(CHEM_PAR)[46];
KT_FeBu_2 = mxGetPr(CHEM_PAR)[47];
KT_FeCl= mxGetPr(CHEM_PAR)[48];
KT_FeCl_2= mxGetPr(CHEM_PAR)[49];
KT_FeH2PO4= mxGetPr(CHEM_PAR)[50];
KT_FeH2PO4_2= mxGetPr(CHEM_PAR)[51];
KT_FeHCO3= mxGetPr(CHEM_PAR)[52];
KT_FeHPO4_aq = mxGetPr(CHEM_PAR)[53];
KT_FeHPO4 = mxGetPr(CHEM_PAR)[54];
KT_FeHS = mxGetPr(CHEM_PAR)[55];
KT_FeNH3 = mxGetPr(CHEM_PAR)[56];
KT_FeOH = mxGetPr(CHEM_PAR)[57];
KT_FeOH_2 = mxGetPr(CHEM_PAR)[58];
KT_FePr = mxGetPr(CHEM_PAR)[59];
KT_FeSO4_aq = mxGetPr(CHEM_PAR)[60];
KT_FeSO4 = mxGetPr(CHEM_PAR)[61];
KT_FeVa_2 = mxGetPr(CHEM_PAR)[62];
KT_H2CO3_aq = mxGetPr(CHEM_PAR)[63];
KT_H2PO4 = mxGetPr(CHEM_PAR)[64];
KT_H2S_aq = mxGetPr(CHEM_PAR)[65];
KT_H3PO4 = mxGetPr(CHEM_PAR)[66];
KT_HAc_aq = mxGetPr(CHEM_PAR)[67];
KT_HBu_aq = mxGetPr(CHEM_PAR)[68];
KT_HCO3 = mxGetPr(CHEM_PAR)[69];
KT_HPO4 = mxGetPr(CHEM_PAR)[70];
KT_HPr_aq = mxGetPr(CHEM_PAR)[71];
KT_HSO4 = mxGetPr(CHEM_PAR)[72];
KT_HVa_aq = mxGetPr(CHEM_PAR)[73];
KT_K2HPO4_aq =mxGetPr(CHEM_PAR)[74];
KT_K2PO4 = mxGetPr(CHEM_PAR)[75];
KT_KAc_aq = mxGetPr(CHEM_PAR)[76];
KT_KCl_aq = mxGetPr(CHEM_PAR)[77];
KT_KH2PO4_aq = mxGetPr(CHEM_PAR)[78];
KT_KHPO4 = mxGetPr(CHEM_PAR)[79];
KT_KOH_aq = mxGetPr(CHEM_PAR)[80];
KT_KPO4 = mxGetPr(CHEM_PAR)[81];
KT_KSO4 = mxGetPr(CHEM_PAR)[82];
KT_MgN2H6 = mxGetPr(CHEM_PAR)[83];
KT_Mg2CO3 = mxGetPr(CHEM_PAR)[84];
KT_MgAc = mxGetPr(CHEM_PAR)[85];
KT_MgBu = mxGetPr(CHEM_PAR)[86];
KT_MgCl = mxGetPr(CHEM_PAR)[87];
KT_MgCO3_aq = mxGetPr(CHEM_PAR)[88];
KT_MgHCO3 = mxGetPr(CHEM_PAR)[89];
KT_MgHPO4_aq =mxGetPr(CHEM_PAR)[90];
KT_MgOH = mxGetPr(CHEM_PAR)[91];
KT_MgPO4 = mxGetPr(CHEM_PAR)[92];
KT_MgPr = mxGetPr(CHEM_PAR)[93];
KT_MgSO4_aq =mxGetPr(CHEM_PAR)[94];
KT_Na2HPO4_aq =mxGetPr(CHEM_PAR)[95];
KT_Na2PO4 = mxGetPr(CHEM_PAR)[96];
KT_NaAc_aq = mxGetPr(CHEM_PAR)[97];
KT_NaCl_aq = mxGetPr(CHEM_PAR)[98];
KT_NaCO3 = mxGetPr(CHEM_PAR)[99];
KT_NaH2PO4_aq =mxGetPr(CHEM_PAR)[100];
KT_NaHCO3_aq = mxGetPr(CHEM_PAR)[101];
KT_NaHPO4 = mxGetPr(CHEM_PAR)[102];
KT_NaOH_aq =mxGetPr(CHEM_PAR)[103];
KT_NaPO4 =mxGetPr(CHEM_PAR)[104];
KT_NaSO4 =mxGetPr(CHEM_PAR)[105];
KT_NH3_aq = mxGetPr(CHEM_PAR)[106];
KT_NH4SO4 = mxGetPr(CHEM_PAR)[107];
KT_H2O = mxGetPr(CHEM_PAR)[108];
KT_S =mxGetPr(CHEM_PAR)[109];
KT_CO2 = mxGetPr(CHEM_PAR)[110];

   d =             mxGetPr(ACTIVITY)[0]; 
   eps =           mxGetPr(ACTIVITY)[1]; 
   A =             mxGetPr(ACTIVITY)[2];
    
Tot_H = u[0];    
Tot_Na = u[1];        // Total concentration of sodium species
Tot_K = u[2];           // Total concentration of potassium species
Tot_NH4 = u[3];         // Total concentration of ammonium species
Tot_Cl = u[4];        // Total concentration of cloride species
Tot_Ac = u[5];         // Total concentration of acetate species
Tot_Pr = u[6];         // Total concentration of propionate species
Tot_Ca = u[7];         // Total concentration of calcium species
Tot_Mg = u[8];         // Total concentration of magnesium species
Tot_CO3 = u[9];        // Total concentration of carbonate species
Tot_SO4 = u[10];        // Total concentration of sulfate species
Tot_PO4 = u[11];        // Total concentration of phosphate species
Tot_Al = u[12];         // Total concentration of aluminium species
Tot_Fe2 = u[13];        // Total concentration of ferrous iron species
Tot_Fe3 = u[14];        // Total concentration of ferric iron species
Tot_HS = u[15];         // Total concentration of hydrogen sulfur species
Tot_Bu = u[16];
Tot_Va = u[17];


Temp_K = Temp_C+273.15;

	
S_act_H = x[0];      // Activity of hydrogen ion
S_act_Na = x[1];     // Activity of sodium ion
S_act_K = x[2];      // Activity of potassium ion
S_act_NH4 = x[3];    // Activity of ammonium ion
S_act_Cl = x[4];     // Activity of chloride ion
S_act_Ac = x[5];     // Activity of acetate ion
S_act_Pr = x[6];     // Activity of proppionate ion
S_act_Ca = x[7];     // Activity of calcium ion
S_act_Mg = x[8];     // Activity of magnesium ion
S_act_CO3 = x[9];    // Activity of carbonate ion
S_act_SO4 = x[10];   // Activity of sulfate ion 
S_act_PO4 = x[11];   // Activity of phosphate ion
S_act_Al = x[12];
S_act_Fe2 = x[13];
S_act_Fe3 = x[14];
S_act_HS = x[15];
S_act_Bu = x[16];
S_act_Va = x[17];
mu = x[18];          // Ionic strength of the solution
gama = x[19];        // Activity coefficient
    
gama2 = pow(gama,4);     // For divalent ions
gama3 = pow(gama,9);     // For trivalent ions
gama4 = pow(gama,16);    // 4 times charged ions
gama5 = pow(gama,25);    // 5 times charged ions    
    
    
Equ[0] =  S_act_H/gama+S_act_K/gama-(S_act_CO3*2.0)/gama2+S_act_NH4/gama-S_act_HS/gama-S_act_Ac/gama-(S_act_PO4*3.0)/gama3+(S_act_Ca*2.0)/gama2-(S_act_SO4*2.0)/gama2+(S_act_Fe2*2.0)/gama2-S_act_Cl/gama+S_act_Na/gama+(S_act_Al*3.0)/gama3+(S_act_Fe3*3.0)/gama3+(S_act_Mg*2.0)/gama2-S_act_Bu/gama-S_act_Va/gama-S_act_Pr/gama-KT_H2O/(S_act_H*gama)-(KT_HCO3*S_act_H*S_act_CO3)/gama-(KT_HPO4*S_act_H*S_act_PO4*2.0)/gama2-(KT_HSO4*S_act_H*S_act_SO4)/gama-(KT_KPO4*S_act_K*S_act_PO4*2.0)/gama2-(KT_KSO4*S_act_K*S_act_SO4)/gama-(KT_NaCO3*S_act_CO3*S_act_Na)/gama+(KT_FeHS*S_act_HS*S_act_Fe2)/gama-(KT_CaPO4*S_act_PO4*S_act_Ca)/gama+(KT_CaAc*S_act_Ac*S_act_Ca)/gama+(KT_FeAc*S_act_Ac*S_act_Fe2)/gama+(KT_AlAc*S_act_Ac*S_act_Al*2.0)/gama2-(KT_NH4SO4*S_act_NH4*S_act_SO4)/gama+(KT_FeSO4*S_act_SO4*S_act_Fe3)/gama-(KT_NaPO4*S_act_PO4*S_act_Na*2.0)/gama2+(KT_CaCl*S_act_Ca*S_act_Cl)/gama+(KT_AlSO4*S_act_SO4*S_act_Al)/gama-(KT_NaSO4*S_act_SO4*S_act_Na)/gama-(KT_MgPO4*S_act_PO4*S_act_Mg)/gama+(KT_MgAc*S_act_Ac*S_act_Mg)/gama+(KT_FeCl*S_act_Fe2*S_act_Cl)/gama+(KT_CaBu*S_act_Ca*S_act_Bu)/gama+(KT_CaVa*S_act_Ca*S_act_Va)/gama+(KT_AlCl*S_act_Al*S_act_Cl*2.0)/gama2+(KT_MgCl*S_act_Cl*S_act_Mg)/gama+(KT_AlBu*S_act_Al*S_act_Bu*2.0)/gama2+(KT_CaPr*S_act_Ca*S_act_Pr)/gama+(KT_MgBu*S_act_Mg*S_act_Bu)/gama+(KT_FePr*S_act_Fe3*S_act_Pr*2.0)/gama2+(KT_AlPr*S_act_Al*S_act_Pr*2.0)/gama2+(KT_MgPr*S_act_Mg*S_act_Pr)/gama+(KT_FeAc_2*S_act_Ac*S_act_Fe3*2.0)/gama2+(KT_FeCl_2*S_act_Fe3*S_act_Cl*2.0)/gama2+(KT_FeBu_2*S_act_Fe3*S_act_Bu*2.0)/gama2+(KT_FeVa_2*S_act_Fe3*S_act_Va*2.0)/gama2-(KT_S*S_act_HS*2.0)/(S_act_H*gama2)-(KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama-(KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4)/gama+(KT_CaOH*S_act_Ca)/(S_act_H*gama)+(KT_FeOH*S_act_Fe2)/(S_act_H*gama)+(KT_AlOH*S_act_Al*2.0)/(S_act_H*gama2)+(KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3)/gama-(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2)/gama+(KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al)/gama-(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3)/gama-(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al)/gama+(KT_MgOH*S_act_Mg)/(S_act_H*gama)+(KT_FeOH_2*S_act_Fe3*2.0)/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3)/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al)/gama+(KT_Mg2CO3*S_act_CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2+(KT_Al2PO4*S_act_PO4*(S_act_Al*S_act_Al)*3.0)/gama3-(KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na))/gama-(KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3)/gama-(KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al)/gama+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*4.0)/gama4+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*5.0)/gama5+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*4.0)/gama4+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*5.0)/gama5+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*2.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*2.0)/gama2+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*2.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*3.0)/gama3+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2-(KT_KHPO4*S_act_H*S_act_K*S_act_PO4)/gama+(KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca)/gama+(KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2)/gama+(KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg)/gama+(KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3)/gama+(KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al)/gama-(KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na)/gama+(KT_CaNH3*S_act_NH4*S_act_Ca*2.0)/(S_act_H*gama2)+(KT_FeNH3*S_act_NH4*S_act_Fe2*2.0)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca)/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2)/gama+(KT_AlOHAc*S_act_Ac*S_act_Al)/(S_act_H*gama)+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe3*2.0)/gama2;


Equ[1] =  -Tot_Na+S_act_Na/gama+KT_NaAc_aq*S_act_Ac*S_act_Na+KT_NaCl_aq*S_act_Cl*S_act_Na+(KT_NaOH_aq*S_act_Na)/S_act_H+KT_Na2HPO4_aq*S_act_H*S_act_PO4*(S_act_Na*S_act_Na)*2.0+KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4*S_act_Na+(KT_NaCO3*S_act_CO3*S_act_Na)/gama+(KT_NaPO4*S_act_PO4*S_act_Na)/gama2+(KT_NaSO4*S_act_SO4*S_act_Na)/gama+(KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*2.0)/gama+KT_NaHCO3_aq*S_act_H*S_act_CO3*S_act_Na+(KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na)/gama;


Equ[2] =  -Tot_K+S_act_K/gama+KT_KAc_aq*S_act_K*S_act_Ac+KT_KCl_aq*S_act_K*S_act_Cl+(KT_KOH_aq*S_act_K)/S_act_H+KT_K2HPO4_aq*S_act_H*(S_act_K*S_act_K)*S_act_PO4*2.0+KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_K*S_act_PO4+(KT_KPO4*S_act_K*S_act_PO4)/gama2+(KT_KSO4*S_act_K*S_act_SO4)/gama+(KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*2.0)/gama+(KT_KHPO4*S_act_H*S_act_K*S_act_PO4)/gama;


Equ[3] =  -Tot_NH4+S_act_NH4/gama+(KT_NH3_aq*S_act_NH4)/S_act_H+(KT_NH4SO4*S_act_NH4*S_act_SO4)/gama+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*2.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*3.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*2.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2+(KT_CaNH3*S_act_NH4*S_act_Ca)/(S_act_H*gama2)+(KT_FeNH3*S_act_NH4*S_act_Fe2)/(S_act_H*gama2);


Equ[4] =  -Tot_Cl+S_act_Cl/gama+KT_KCl_aq*S_act_K*S_act_Cl+KT_NaCl_aq*S_act_Cl*S_act_Na+(KT_CaCl*S_act_Ca*S_act_Cl)/gama+(KT_FeCl*S_act_Fe2*S_act_Cl)/gama+(KT_AlCl*S_act_Al*S_act_Cl)/gama2+(KT_MgCl*S_act_Cl*S_act_Mg)/gama+(KT_FeCl_2*S_act_Fe3*S_act_Cl)/gama2;


Equ[5] =  -Tot_Ac+S_act_Ac/gama+KT_HAc_aq*S_act_H*S_act_Ac+KT_KAc_aq*S_act_K*S_act_Ac+KT_NaAc_aq*S_act_Ac*S_act_Na+KT_FeAc3_aq*(S_act_Ac*S_act_Ac*S_act_Ac)*S_act_Fe3*3.0+(KT_CaAc*S_act_Ac*S_act_Ca)/gama+(KT_FeAc*S_act_Ac*S_act_Fe2)/gama+(KT_AlAc*S_act_Ac*S_act_Al)/gama2+(KT_MgAc*S_act_Ac*S_act_Mg)/gama+(KT_FeAc_2*S_act_Ac*S_act_Fe3)/gama2+(KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*2.0)/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*2.0)/gama+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al))/gama3+(KT_AlOHAc*S_act_Ac*S_act_Al)/(S_act_H*gama);


Equ[6] =  -Tot_Pr+S_act_Pr/gama+KT_HPr_aq*S_act_H*S_act_Pr+(KT_CaPr*S_act_Ca*S_act_Pr)/gama+(KT_FePr*S_act_Fe3*S_act_Pr)/gama2+(KT_AlPr*S_act_Al*S_act_Pr)/gama2+(KT_MgPr*S_act_Mg*S_act_Pr)/gama;


Equ[7] =  -Tot_Ca+S_act_Ca/gama2+KT_CaCO3_aq*S_act_CO3*S_act_Ca+KT_CaSO4_aq*S_act_Ca*S_act_SO4+(KT_CaPO4*S_act_PO4*S_act_Ca)/gama+(KT_CaAc*S_act_Ac*S_act_Ca)/gama+(KT_CaCl*S_act_Ca*S_act_Cl)/gama+(KT_CaBu*S_act_Ca*S_act_Bu)/gama+(KT_CaVa*S_act_Ca*S_act_Va)/gama+(KT_CaPr*S_act_Ca*S_act_Pr)/gama+(KT_CaOH*S_act_Ca)/(S_act_H*gama)+KT_CaHPO4_aq*S_act_H*S_act_PO4*S_act_Ca+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca)/gama2+(KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca)/gama+(KT_CaNH3*S_act_NH4*S_act_Ca)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca)/gama;


Equ[8] =  -Tot_Mg+S_act_Mg/gama2+KT_MgCO3_aq*S_act_CO3*S_act_Mg+KT_MgSO4_aq*S_act_SO4*S_act_Mg+(KT_MgPO4*S_act_PO4*S_act_Mg)/gama+(KT_MgAc*S_act_Ac*S_act_Mg)/gama+(KT_MgCl*S_act_Cl*S_act_Mg)/gama+(KT_MgBu*S_act_Mg*S_act_Bu)/gama+(KT_MgPr*S_act_Mg*S_act_Pr)/gama+(KT_MgOH*S_act_Mg)/(S_act_H*gama)+(KT_Mg2CO3*S_act_CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2+KT_MgHPO4_aq*S_act_H*S_act_PO4*S_act_Mg+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg)/gama2+(KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg)/gama;


Equ[9] =  -Tot_CO3+S_act_CO3/gama2+KT_CaCO3_aq*S_act_CO3*S_act_Ca+KT_MgCO3_aq*S_act_CO3*S_act_Mg+KT_CO2*(S_act_H*S_act_H)*S_act_CO3+KT_H2CO3_aq*(S_act_H*S_act_H)*S_act_CO3+(KT_HCO3*S_act_H*S_act_CO3)/gama+(KT_NaCO3*S_act_CO3*S_act_Na)/gama+(KT_Mg2CO3*S_act_CO3*(S_act_Mg*S_act_Mg))/gama2+KT_NaHCO3_aq*S_act_H*S_act_CO3*S_act_Na+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al))/gama2+(KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca)/gama+(KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2)/gama+(KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg)/gama;


Equ[10] =  -Tot_SO4+S_act_SO4/gama2+KT_CaSO4_aq*S_act_Ca*S_act_SO4+KT_FeSO4_aq*S_act_SO4*S_act_Fe2+KT_MgSO4_aq*S_act_SO4*S_act_Mg+(KT_HSO4*S_act_H*S_act_SO4)/gama+(KT_KSO4*S_act_K*S_act_SO4)/gama+(KT_NH4SO4*S_act_NH4*S_act_SO4)/gama+(KT_FeSO4*S_act_SO4*S_act_Fe3)/gama+(KT_AlSO4*S_act_SO4*S_act_Al)/gama+(KT_NaSO4*S_act_SO4*S_act_Na)/gama+(KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*2.0)/gama+(KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*2.0)/gama;


Equ[11] =  -Tot_PO4+S_act_PO4/gama3+KT_H3PO4*(S_act_H*S_act_H*S_act_H)*S_act_PO4+KT_K2HPO4_aq*S_act_H*(S_act_K*S_act_K)*S_act_PO4+KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_K*S_act_PO4+KT_Na2HPO4_aq*S_act_H*S_act_PO4*(S_act_Na*S_act_Na)+KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4*S_act_Na+(KT_HPO4*S_act_H*S_act_PO4)/gama2+(KT_KPO4*S_act_K*S_act_PO4)/gama2+(KT_CaPO4*S_act_PO4*S_act_Ca)/gama+(KT_NaPO4*S_act_PO4*S_act_Na)/gama2+(KT_MgPO4*S_act_PO4*S_act_Mg)/gama+(KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama+(KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4)/gama+(KT_Al2PO4*S_act_PO4*(S_act_Al*S_act_Al))/gama3+(KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na))/gama+KT_CaHPO4_aq*S_act_H*S_act_PO4*S_act_Ca+KT_FeHPO4_aq*S_act_H*S_act_PO4*S_act_Fe2+KT_MgHPO4_aq*S_act_H*S_act_PO4*S_act_Mg+(KT_KHPO4*S_act_H*S_act_K*S_act_PO4)/gama+(KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3)/gama+(KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al)/gama+(KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na)/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca)/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe3)/gama2;


Equ[12] =  -Tot_Al+S_act_Al/gama3+KT_AlOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Al+(KT_AlAc*S_act_Ac*S_act_Al)/gama2+(KT_AlSO4*S_act_SO4*S_act_Al)/gama+(KT_AlCl*S_act_Al*S_act_Cl)/gama2+(KT_AlBu*S_act_Al*S_act_Bu)/gama2+(KT_AlPr*S_act_Al*S_act_Pr)/gama2+(KT_AlOH*S_act_Al)/(S_act_H*gama2)+(KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al)/gama+(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al)/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al)/gama+(KT_Al2PO4*S_act_PO4*(S_act_Al*S_act_Al)*2.0)/gama3+(KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al)/gama+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*2.0)/gama4+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*3.0)/gama5+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*2.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*2.0)/gama3+(KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al)/gama+(KT_AlOHAc*S_act_Ac*S_act_Al)/(S_act_H*gama);


Equ[13] =  -Tot_Fe2+S_act_Fe2/gama2+KT_FeSO4_aq*S_act_SO4*S_act_Fe2+KT_FeOH2_aq*1.0/(S_act_H*S_act_H)*S_act_Fe2+(KT_FeHS*S_act_HS*S_act_Fe2)/gama+(KT_FeAc*S_act_Ac*S_act_Fe2)/gama+(KT_FeCl*S_act_Fe2*S_act_Cl)/gama+(KT_FeOH*S_act_Fe2)/(S_act_H*gama)+(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2)/gama+KT_FeHPO4_aq*S_act_H*S_act_PO4*S_act_Fe2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2)/gama2+(KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2)/gama+(KT_FeNH3*S_act_NH4*S_act_Fe2)/(S_act_H*gama2)+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2)/gama;


Equ[14] =  -Tot_Fe3+S_act_Fe3/gama3+KT_FeOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe3+KT_FeAc3_aq*(S_act_Ac*S_act_Ac*S_act_Ac)*S_act_Fe3+(KT_FeSO4*S_act_SO4*S_act_Fe3)/gama+(KT_FePr*S_act_Fe3*S_act_Pr)/gama2+(KT_FeAc_2*S_act_Ac*S_act_Fe3)/gama2+(KT_FeCl_2*S_act_Fe3*S_act_Cl)/gama2+(KT_FeBu_2*S_act_Fe3*S_act_Bu)/gama2+(KT_FeVa_2*S_act_Fe3*S_act_Va)/gama2+(KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3)/gama+(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3)/gama+(KT_FeOH_2*S_act_Fe3)/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3)/gama+(KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3)/gama+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*2.0)/gama4+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*3.0)/gama5+(KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe3)/gama2;


Equ[15] =  -Tot_HS+S_act_HS/gama+KT_H2S_aq*S_act_H*S_act_HS+(KT_FeHS*S_act_HS*S_act_Fe2)/gama+(KT_S*S_act_HS)/(S_act_H*gama2);


Equ[16] =  -Tot_Bu+S_act_Bu/gama+KT_HBu_aq*S_act_H*S_act_Bu+(KT_CaBu*S_act_Ca*S_act_Bu)/gama+(KT_AlBu*S_act_Al*S_act_Bu)/gama2+(KT_MgBu*S_act_Mg*S_act_Bu)/gama+(KT_FeBu_2*S_act_Fe3*S_act_Bu)/gama2;


Equ[17] =  -Tot_Va+S_act_Va/gama+KT_HVa_aq*S_act_H*S_act_Va+(KT_CaVa*S_act_Ca*S_act_Va)/gama+(KT_FeVa_2*S_act_Fe3*S_act_Va)/gama2;


Equ[18] =  -mu+(S_act_H*(1.0/2.0))/gama+(S_act_K*(1.0/2.0))/gama+(S_act_CO3*2.0)/gama2+(S_act_NH4*(1.0/2.0))/gama+(S_act_HS*(1.0/2.0))/gama+(S_act_Ac*(1.0/2.0))/gama+(S_act_PO4*(9.0/2.0))/gama3+(S_act_Ca*2.0)/gama2+(S_act_SO4*2.0)/gama2+(S_act_Fe2*2.0)/gama2+(S_act_Cl*(1.0/2.0))/gama+(S_act_Na*(1.0/2.0))/gama+(S_act_Al*(9.0/2.0))/gama3+(S_act_Fe3*(9.0/2.0))/gama3+(S_act_Mg*2.0)/gama2+(S_act_Bu*(1.0/2.0))/gama+(S_act_Va*(1.0/2.0))/gama+(S_act_Pr*(1.0/2.0))/gama+(KT_H2O*(1.0/2.0))/(S_act_H*gama)+(KT_HCO3*S_act_H*S_act_CO3*(1.0/2.0))/gama+(KT_HPO4*S_act_H*S_act_PO4*2.0)/gama2+(KT_HSO4*S_act_H*S_act_SO4*(1.0/2.0))/gama+(KT_KPO4*S_act_K*S_act_PO4*2.0)/gama2+(KT_KSO4*S_act_K*S_act_SO4*(1.0/2.0))/gama+(KT_NaCO3*S_act_CO3*S_act_Na*(1.0/2.0))/gama+(KT_FeHS*S_act_HS*S_act_Fe2*(1.0/2.0))/gama+(KT_CaPO4*S_act_PO4*S_act_Ca*(1.0/2.0))/gama+(KT_CaAc*S_act_Ac*S_act_Ca*(1.0/2.0))/gama+(KT_FeAc*S_act_Ac*S_act_Fe2*(1.0/2.0))/gama+(KT_AlAc*S_act_Ac*S_act_Al*2.0)/gama2+(KT_NH4SO4*S_act_NH4*S_act_SO4*(1.0/2.0))/gama+(KT_FeSO4*S_act_SO4*S_act_Fe3*(1.0/2.0))/gama+(KT_NaPO4*S_act_PO4*S_act_Na*2.0)/gama2+(KT_CaCl*S_act_Ca*S_act_Cl*(1.0/2.0))/gama+(KT_AlSO4*S_act_SO4*S_act_Al)/gama+(KT_NaSO4*S_act_SO4*S_act_Na*(1.0/2.0))/gama+(KT_MgPO4*S_act_PO4*S_act_Mg*(1.0/2.0))/gama+(KT_MgAc*S_act_Ac*S_act_Mg*(1.0/2.0))/gama+(KT_FeCl*S_act_Fe2*S_act_Cl*(1.0/2.0))/gama+(KT_CaBu*S_act_Ca*S_act_Bu*(1.0/2.0))/gama+(KT_CaVa*S_act_Ca*S_act_Va*(1.0/2.0))/gama+(KT_AlCl*S_act_Al*S_act_Cl*2.0)/gama2+(KT_MgCl*S_act_Cl*S_act_Mg*(1.0/2.0))/gama+(KT_AlBu*S_act_Al*S_act_Bu*2.0)/gama2+(KT_CaPr*S_act_Ca*S_act_Pr*(1.0/2.0))/gama+(KT_MgBu*S_act_Mg*S_act_Bu*(1.0/2.0))/gama+(KT_FePr*S_act_Fe3*S_act_Pr*2.0)/gama2+(KT_AlPr*S_act_Al*S_act_Pr*2.0)/gama2+(KT_MgPr*S_act_Mg*S_act_Pr*(1.0/2.0))/gama+(KT_FeAc_2*S_act_Ac*S_act_Fe3*2.0)/gama2+(KT_FeCl_2*S_act_Fe3*S_act_Cl*2.0)/gama2+(KT_FeBu_2*S_act_Fe3*S_act_Bu*2.0)/gama2+(KT_FeVa_2*S_act_Fe3*S_act_Va*2.0)/gama2+(KT_S*S_act_HS*2.0)/(S_act_H*gama2)+(KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4*(1.0/2.0))/gama+(KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*(1.0/2.0))/gama+(KT_CaOH*S_act_Ca*(1.0/2.0))/(S_act_H*gama)+(KT_FeOH*S_act_Fe2*(1.0/2.0))/(S_act_H*gama)+(KT_AlOH*S_act_Al*2.0)/(S_act_H*gama2)+(KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3*(1.0/2.0))/gama+(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2*(1.0/2.0))/gama+(KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al*(1.0/2.0))/gama+(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*(1.0/2.0))/gama+(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*(1.0/2.0))/gama+(KT_MgOH*S_act_Mg*(1.0/2.0))/(S_act_H*gama)+(KT_FeOH_2*S_act_Fe3*2.0)/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*(1.0/2.0))/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*(1.0/2.0))/gama+(KT_Mg2CO3*S_act_CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2+(KT_Al2PO4*S_act_PO4*(S_act_Al*S_act_Al)*(9.0/2.0))/gama3+(KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*(1.0/2.0))/gama+(KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*(1.0/2.0))/gama+(KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*(1.0/2.0))/gama+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*8.0)/gama4+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*(2.5E1/2.0))/gama5+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*8.0)/gama4+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*(2.5E1/2.0))/gama5+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*2.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*2.0)/gama2+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*2.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*(9.0/2.0))/gama3+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2+(KT_KHPO4*S_act_H*S_act_K*S_act_PO4*(1.0/2.0))/gama+(KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca*(1.0/2.0))/gama+(KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2*(1.0/2.0))/gama+(KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg*(1.0/2.0))/gama+(KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3*(1.0/2.0))/gama+(KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al*(1.0/2.0))/gama+(KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na*(1.0/2.0))/gama+(KT_CaNH3*S_act_NH4*S_act_Ca*2.0)/(S_act_H*gama2)+(KT_FeNH3*S_act_NH4*S_act_Fe2*2.0)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca*(1.0/2.0))/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2*(1.0/2.0))/gama+(KT_AlOHAc*S_act_Ac*S_act_Al*(1.0/2.0))/(S_act_H*gama)+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe3*2.0)/gama2;


Equ[19] =  -gama+pow(1.0E1,A*(mu*(3.0/1.0E1)-sqrt(mu)/(sqrt(mu)+1.0)));


   return 1;
}

 bool JacAna(const double x[], double *jac)
{
	SimStruct *S;
    double *u;
    
double KT_AlAc2,KT_AlOH2,KT_AlOH3_aq,KT_AlOH4,KT_AlS2O8,KT_Al2OH8,KT_Al2OH2Ac,KT_AlOH2CO3,KT_Al2PO4,KT_Al3OH4,KT_AlAc,KT_AlBu,KT_AlCl,KT_AlHPO4,KT_AlOH; 
double KT_AlOHAc,KT_AlPr,KT_AlSO4,KT_CaN2H6,KT_CaAc,KT_CaBu,KT_CaCl,KT_CaCO3_aq,KT_CaH2PO4,KT_CaHCO3,KT_CaHPO4_aq,KT_CaNH3,KT_CaOH,KT_CaPO4,KT_CaPr,KT_CaSO4_aq,KT_CaVa,KT_FeAc2,KT_FeAc3_aq,KT_FeN2H6,KT_FeN3H9,KT_FeN4H12,KT_FeOH2_aq,KT_FeOH2;
double KT_FeOH3,KT_FeOH3_aq,KT_FeOH4,KT_FeS2O8,KT_Fe2O2H2,KT_Fe3O4H4,KT_FeAc,KT_FeAc_2,KT_FeBu_2,KT_FeCl,KT_FeCl_2,KT_FeH2PO4,KT_FeH2PO4_2,KT_FeHCO3,KT_FeHPO4_aq,KT_FeHPO4,KT_FeHS,KT_FeNH3,KT_FeOH,KT_FeOH_2,KT_FePr,KT_FeSO4_aq,KT_FeSO4,KT_FeVa_2,KT_H2CO3_aq,KT_H2PO4,KT_H2S_aq,KT_H3PO4,KT_HAc_aq,KT_HBu_aq,KT_HCO3,KT_HPO4,KT_HPr_aq,KT_HSO4,KT_HVa_aq,KT_K2HPO4_aq,KT_K2PO4,KT_KAc_aq,KT_KCl_aq,KT_KH2PO4_aq,KT_KHPO4,KT_KOH_aq,KT_KPO4,KT_KSO4; 
double KT_MgN2H6,KT_Mg2CO3,KT_MgAc,KT_MgBu,KT_MgCl,KT_MgCO3_aq,KT_MgHCO3,KT_MgHPO4_aq,KT_MgOH,KT_MgPO4,KT_MgPr,KT_MgSO4_aq,KT_Na2HPO4_aq,KT_Na2PO4,KT_NaAc_aq,KT_NaCl_aq,KT_NaCO3,KT_NaH2PO4_aq,KT_NaHCO3_aq,KT_NaHPO4,KT_NaOH_aq,KT_NaPO4,KT_NaSO4,KT_NH3_aq,KT_NH4SO4,KT_H2O,KT_S,KT_CO2;

double d, eps, A;

double S_act_H, S_act_Na, S_act_K, S_act_NH4,S_act_Cl,S_act_Ac,S_act_Pr, S_act_Ca, S_act_Mg, S_act_CO3, S_act_SO4,S_act_PO4, S_act_Al, S_act_Fe2, S_act_Fe3, S_act_HS, S_act_Bu, S_act_Va, mu, gama;
double Tot_H,Tot_Na, Tot_K, Tot_NH4, Tot_Cl, Tot_Ac, Tot_Pr, Tot_Ca, Tot_Mg, Tot_CO3, Tot_SO4, Tot_PO4, Tot_Al, Tot_Fe2, Tot_Fe3, Tot_HS, Tot_Bu, Tot_Va, Temp_C, Temp_K;
double gama2, gama3, gama4, gama5;
	
    
double gradEqu[400];
	
    unsigned int i,j;
	bool status = 1;

	S=Smain;
    u=umain;
    
KT_AlAc2 = mxGetPr(CHEM_PAR)[0]; 
KT_AlOH2 = mxGetPr(CHEM_PAR)[1];
KT_AlOH3_aq = mxGetPr(CHEM_PAR)[2];
KT_AlOH4 = mxGetPr(CHEM_PAR)[3];
KT_AlS2O8 = mxGetPr(CHEM_PAR)[4];
KT_Al2OH8 = mxGetPr(CHEM_PAR)[5];
KT_Al2OH2Ac = mxGetPr(CHEM_PAR)[6];
KT_AlOH2CO3 = mxGetPr(CHEM_PAR)[7];
KT_Al2PO4 = mxGetPr(CHEM_PAR)[8];
KT_Al3OH4 = mxGetPr(CHEM_PAR)[9];
KT_AlBu = mxGetPr(CHEM_PAR)[10];
KT_AlAc = mxGetPr(CHEM_PAR)[11];
KT_AlCl = mxGetPr(CHEM_PAR)[12];
KT_AlHPO4 = mxGetPr(CHEM_PAR)[13];
KT_AlOH = mxGetPr(CHEM_PAR)[14];
KT_AlOHAc = mxGetPr(CHEM_PAR)[15];
KT_AlPr = mxGetPr(CHEM_PAR)[16];
KT_AlSO4 = mxGetPr(CHEM_PAR)[17];
KT_CaN2H6 = mxGetPr(CHEM_PAR)[18];
KT_CaAc = mxGetPr(CHEM_PAR)[19];
KT_CaBu = mxGetPr(CHEM_PAR)[20];
KT_CaCl = mxGetPr(CHEM_PAR)[21];
KT_CaH2PO4 = mxGetPr(CHEM_PAR)[22];
KT_CaCO3_aq = mxGetPr(CHEM_PAR)[23];
KT_CaHCO3 = mxGetPr(CHEM_PAR)[24];
KT_CaHPO4_aq = mxGetPr(CHEM_PAR)[25];
KT_CaNH3 = mxGetPr(CHEM_PAR)[26];
KT_CaOH = mxGetPr(CHEM_PAR)[27];
KT_CaPO4 = mxGetPr(CHEM_PAR)[28];
KT_CaPr = mxGetPr(CHEM_PAR)[29];
KT_CaSO4_aq = mxGetPr(CHEM_PAR)[30];
KT_CaVa = mxGetPr(CHEM_PAR)[31];
KT_FeAc2 = mxGetPr(CHEM_PAR)[32];
KT_FeAc3_aq = mxGetPr(CHEM_PAR)[33];
KT_FeN2H6 = mxGetPr(CHEM_PAR)[34];
KT_FeN3H9 = mxGetPr(CHEM_PAR)[35];
KT_FeN4H12 = mxGetPr(CHEM_PAR)[36];
KT_FeOH2_aq = mxGetPr(CHEM_PAR)[37];
KT_FeOH2 = mxGetPr(CHEM_PAR)[38];
KT_FeOH3 = mxGetPr(CHEM_PAR)[39];
KT_FeOH3_aq = mxGetPr(CHEM_PAR)[40];
KT_FeOH4= mxGetPr(CHEM_PAR)[41];
KT_FeS2O8= mxGetPr(CHEM_PAR)[42];
KT_Fe2O2H2= mxGetPr(CHEM_PAR)[43];
KT_Fe3O4H4= mxGetPr(CHEM_PAR)[44];
KT_FeAc= mxGetPr(CHEM_PAR)[45];
KT_FeAc_2= mxGetPr(CHEM_PAR)[46];
KT_FeBu_2 = mxGetPr(CHEM_PAR)[47];
KT_FeCl= mxGetPr(CHEM_PAR)[48];
KT_FeCl_2= mxGetPr(CHEM_PAR)[49];
KT_FeH2PO4= mxGetPr(CHEM_PAR)[50];
KT_FeH2PO4_2= mxGetPr(CHEM_PAR)[51];
KT_FeHCO3= mxGetPr(CHEM_PAR)[52];
KT_FeHPO4_aq = mxGetPr(CHEM_PAR)[53];
KT_FeHPO4 = mxGetPr(CHEM_PAR)[54];
KT_FeHS = mxGetPr(CHEM_PAR)[55];
KT_FeNH3 = mxGetPr(CHEM_PAR)[56];
KT_FeOH = mxGetPr(CHEM_PAR)[57];
KT_FeOH_2 = mxGetPr(CHEM_PAR)[58];
KT_FePr = mxGetPr(CHEM_PAR)[59];
KT_FeSO4_aq = mxGetPr(CHEM_PAR)[60];
KT_FeSO4 = mxGetPr(CHEM_PAR)[61];
KT_FeVa_2 = mxGetPr(CHEM_PAR)[62];
KT_H2CO3_aq = mxGetPr(CHEM_PAR)[63];
KT_H2PO4 = mxGetPr(CHEM_PAR)[64];
KT_H2S_aq = mxGetPr(CHEM_PAR)[65];
KT_H3PO4 = mxGetPr(CHEM_PAR)[66];
KT_HAc_aq = mxGetPr(CHEM_PAR)[67];
KT_HBu_aq = mxGetPr(CHEM_PAR)[68];
KT_HCO3 = mxGetPr(CHEM_PAR)[69];
KT_HPO4 = mxGetPr(CHEM_PAR)[70];
KT_HPr_aq = mxGetPr(CHEM_PAR)[71];
KT_HSO4 = mxGetPr(CHEM_PAR)[72];
KT_HVa_aq = mxGetPr(CHEM_PAR)[73];
KT_K2HPO4_aq =mxGetPr(CHEM_PAR)[74];
KT_K2PO4 = mxGetPr(CHEM_PAR)[75];
KT_KAc_aq = mxGetPr(CHEM_PAR)[76];
KT_KCl_aq = mxGetPr(CHEM_PAR)[77];
KT_KH2PO4_aq = mxGetPr(CHEM_PAR)[78];
KT_KHPO4 = mxGetPr(CHEM_PAR)[79];
KT_KOH_aq = mxGetPr(CHEM_PAR)[80];
KT_KPO4 = mxGetPr(CHEM_PAR)[81];
KT_KSO4 = mxGetPr(CHEM_PAR)[82];
KT_MgN2H6 = mxGetPr(CHEM_PAR)[83];
KT_Mg2CO3 = mxGetPr(CHEM_PAR)[84];
KT_MgAc = mxGetPr(CHEM_PAR)[85];
KT_MgBu = mxGetPr(CHEM_PAR)[86];
KT_MgCl = mxGetPr(CHEM_PAR)[87];
KT_MgCO3_aq = mxGetPr(CHEM_PAR)[88];
KT_MgHCO3 = mxGetPr(CHEM_PAR)[89];
KT_MgHPO4_aq =mxGetPr(CHEM_PAR)[90];
KT_MgOH = mxGetPr(CHEM_PAR)[91];
KT_MgPO4 = mxGetPr(CHEM_PAR)[92];
KT_MgPr = mxGetPr(CHEM_PAR)[93];
KT_MgSO4_aq =mxGetPr(CHEM_PAR)[94];
KT_Na2HPO4_aq =mxGetPr(CHEM_PAR)[95];
KT_Na2PO4 = mxGetPr(CHEM_PAR)[96];
KT_NaAc_aq = mxGetPr(CHEM_PAR)[97];
KT_NaCl_aq = mxGetPr(CHEM_PAR)[98];
KT_NaCO3 = mxGetPr(CHEM_PAR)[99];
KT_NaH2PO4_aq =mxGetPr(CHEM_PAR)[100];
KT_NaHCO3_aq = mxGetPr(CHEM_PAR)[101];
KT_NaHPO4 = mxGetPr(CHEM_PAR)[102];
KT_NaOH_aq =mxGetPr(CHEM_PAR)[103];
KT_NaPO4 =mxGetPr(CHEM_PAR)[104];
KT_NaSO4 =mxGetPr(CHEM_PAR)[105];
KT_NH3_aq = mxGetPr(CHEM_PAR)[106];
KT_NH4SO4 = mxGetPr(CHEM_PAR)[107];
KT_H2O = mxGetPr(CHEM_PAR)[108];
KT_S =mxGetPr(CHEM_PAR)[109];
KT_CO2 = mxGetPr(CHEM_PAR)[110];

   d =             mxGetPr(ACTIVITY)[0]; 
   eps =           mxGetPr(ACTIVITY)[1]; 
   A =             mxGetPr(ACTIVITY)[2];
   
Tot_H = u[0];    
Tot_Na = u[1];        // Total concentration of sodium species
Tot_K = u[2];           // Total concentration of potassium species
Tot_NH4 = u[3];         // Total concentration of ammonium species
Tot_Cl = u[4];        // Total concentration of cloride species
Tot_Ac = u[5];         // Total concentration of acetate species
Tot_Pr = u[6];         // Total concentration of propionate species
Tot_Ca = u[7];         // Total concentration of calcium species
Tot_Mg = u[8];         // Total concentration of magnesium species
Tot_CO3 = u[9];        // Total concentration of carbonate species
Tot_SO4 = u[10];        // Total concentration of sulfate species
Tot_PO4 = u[11];        // Total concentration of phosphate species
Tot_Al = u[12];         // Total concentration of aluminium species
Tot_Fe2 = u[13];        // Total concentration of ferrous iron species
Tot_Fe3 = u[14];        // Total concentration of ferric iron species
Tot_HS = u[15];         // Total concentration of hydrogen sulfur species
Tot_Bu = u[16];
Tot_Va = u[17];


Temp_K = Temp_C+273.15;

S_act_H = x[0];      // Activity of hydrogen ion
S_act_Na = x[1];     // Activity of sodium ion
S_act_K = x[2];      // Activity of potassium ion
S_act_NH4 = x[3];    // Activity of ammonium ion
S_act_Cl = x[4];     // Activity of chloride ion
S_act_Ac = x[5];     // Activity of acetate ion
S_act_Pr = x[6];     // Activity of proppionate ion
S_act_Ca = x[7];     // Activity of calcium ion
S_act_Mg = x[8];     // Activity of magnesium ion
S_act_CO3 = x[9];    // Activity of carbonate ion
S_act_SO4 = x[10];   // Activity of sulfate ion 
S_act_PO4 = x[11];   // Activity of phosphate ion
S_act_Al = x[12];
S_act_Fe2 = x[13];
S_act_Fe3 = x[14];
S_act_HS = x[15];
S_act_Bu = x[16];
S_act_Va = x[17];
mu = x[18];          // Ionic strength of the solution
gama = x[19];        // Activity coefficient

gama2 = pow(gama,4);     // For divalent ions
gama3 = pow(gama,9);     // For trivalent ions
gama4 = pow(gama,16);    // 4 times charged ions
gama5 = pow(gama,25);    // 5 times charged ions    
	
	
// Eq1: Charge balance

gradEqu[0] =  1.0/gama+(KT_H2O*1.0/(S_act_H*S_act_H))/gama-(KT_HCO3*S_act_CO3)/gama-(KT_HPO4*S_act_PO4*2.0)/gama2-(KT_HSO4*S_act_SO4)/gama-(KT_H2PO4*S_act_H*S_act_PO4*2.0)/gama-(KT_KHPO4*S_act_K*S_act_PO4)/gama+(KT_CaHCO3*S_act_CO3*S_act_Ca)/gama+(KT_FeHCO3*S_act_CO3*S_act_Fe2)/gama+(KT_MgHCO3*S_act_CO3*S_act_Mg)/gama+(KT_FeHPO4*S_act_PO4*S_act_Fe3)/gama+(KT_AlHPO4*S_act_PO4*S_act_Al)/gama-(KT_NaHPO4*S_act_PO4*S_act_Na)/gama+(KT_S*1.0/(S_act_H*S_act_H)*S_act_HS*2.0)/gama2-(KT_CaOH*1.0/(S_act_H*S_act_H)*S_act_Ca)/gama-(KT_FeOH*1.0/(S_act_H*S_act_H)*S_act_Fe2)/gama-(KT_AlOH*1.0/(S_act_H*S_act_H)*S_act_Al*2.0)/gama2-(KT_FeOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe3*2.0)/gama+(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe2*3.0)/gama-(KT_AlOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Al*2.0)/gama+(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*4.0)/gama+(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*4.0)/gama-(KT_MgOH*1.0/(S_act_H*S_act_H)*S_act_Mg)/gama-(KT_FeOH_2*1.0/(S_act_H*S_act_H)*S_act_Fe3*2.0)/gama2-(KT_Al2OH8*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*8.0)/gama4-(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*2.0E1)/gama5-(KT_Fe2O2H2*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*8.0)/gama4-(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*2.0E1)/gama5-(KT_CaN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*4.0)/gama2-(KT_FeN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2-(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*6.0)/gama2-(KT_MgN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*4.0)/gama2-(KT_AlOH2CO3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*4.0)/gama2-(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*6.0)/gama3-(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*8.0)/gama2+(KT_CaH2PO4*S_act_H*S_act_PO4*S_act_Ca*2.0)/gama+(KT_FeH2PO4*S_act_H*S_act_PO4*S_act_Fe2*2.0)/gama+(KT_FeH2PO4_2*S_act_H*S_act_PO4*S_act_Fe3*4.0)/gama2-(KT_CaNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*2.0)/gama2-(KT_FeNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*2.0)/gama2-(KT_AlOHAc*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al)/gama;


gradEqu[1] =  1.0/gama-(KT_NaCO3*S_act_CO3)/gama-(KT_NaPO4*S_act_PO4*2.0)/gama2-(KT_NaSO4*S_act_SO4)/gama-(KT_NaHPO4*S_act_H*S_act_PO4)/gama-(KT_Na2PO4*S_act_PO4*S_act_Na*2.0)/gama;


gradEqu[2] =  1.0/gama-(KT_KPO4*S_act_PO4*2.0)/gama2-(KT_KSO4*S_act_SO4)/gama-(KT_K2PO4*S_act_K*S_act_PO4*2.0)/gama-(KT_KHPO4*S_act_H*S_act_PO4)/gama;


gradEqu[3] =  1.0/gama-(KT_NH4SO4*S_act_SO4)/gama+(KT_CaNH3*S_act_Ca*2.0)/(S_act_H*gama2)+(KT_FeNH3*S_act_Fe2*2.0)/(S_act_H*gama2)+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*6.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*8.0)/gama2+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*4.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Mg*4.0)/gama2;


gradEqu[4] =  -1.0/gama+(KT_CaCl*S_act_Ca)/gama+(KT_FeCl*S_act_Fe2)/gama+(KT_AlCl*S_act_Al*2.0)/gama2+(KT_MgCl*S_act_Mg)/gama+(KT_FeCl_2*S_act_Fe3*2.0)/gama2;


gradEqu[5] =  -1.0/gama+(KT_CaAc*S_act_Ca)/gama+(KT_FeAc*S_act_Fe2)/gama+(KT_AlAc*S_act_Al*2.0)/gama2+(KT_MgAc*S_act_Mg)/gama+(KT_FeAc_2*S_act_Fe3*2.0)/gama2+(KT_FeAc2*S_act_Ac*S_act_Fe3*2.0)/gama+(KT_AlAc2*S_act_Ac*S_act_Al*2.0)/gama+(KT_AlOHAc*S_act_Al)/(S_act_H*gama)+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*3.0)/gama3;


gradEqu[6] =  -1.0/gama+(KT_CaPr*S_act_Ca)/gama+(KT_FePr*S_act_Fe3*2.0)/gama2+(KT_AlPr*S_act_Al*2.0)/gama2+(KT_MgPr*S_act_Mg)/gama;


gradEqu[7] =  2.0/gama2+KT_CaOH/(S_act_H*gama)-(KT_CaPO4*S_act_PO4)/gama+(KT_CaAc*S_act_Ac)/gama+(KT_CaCl*S_act_Cl)/gama+(KT_CaBu*S_act_Bu)/gama+(KT_CaVa*S_act_Va)/gama+(KT_CaPr*S_act_Pr)/gama+(KT_CaHCO3*S_act_H*S_act_CO3)/gama+(KT_CaNH3*S_act_NH4*2.0)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[8] =  2.0/gama2+KT_MgOH/(S_act_H*gama)-(KT_MgPO4*S_act_PO4)/gama+(KT_MgAc*S_act_Ac)/gama+(KT_MgCl*S_act_Cl)/gama+(KT_MgBu*S_act_Bu)/gama+(KT_MgPr*S_act_Pr)/gama+(KT_MgHCO3*S_act_H*S_act_CO3)/gama+(KT_Mg2CO3*S_act_CO3*S_act_Mg*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[9] =  -2.0/gama2+(KT_Mg2CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2-(KT_HCO3*S_act_H)/gama-(KT_NaCO3*S_act_Na)/gama+(KT_CaHCO3*S_act_H*S_act_Ca)/gama+(KT_FeHCO3*S_act_H*S_act_Fe2)/gama+(KT_MgHCO3*S_act_H*S_act_Mg)/gama+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*2.0)/gama2;


gradEqu[10] =  -2.0/gama2-(KT_HSO4*S_act_H)/gama-(KT_KSO4*S_act_K)/gama-(KT_NH4SO4*S_act_NH4)/gama+(KT_FeSO4*S_act_Fe3)/gama+(KT_AlSO4*S_act_Al)/gama-(KT_NaSO4*S_act_Na)/gama-(KT_FeS2O8*S_act_SO4*S_act_Fe3*2.0)/gama-(KT_AlS2O8*S_act_SO4*S_act_Al*2.0)/gama;


gradEqu[11] =  -3.0/gama3-(KT_H2PO4*(S_act_H*S_act_H))/gama-(KT_K2PO4*(S_act_K*S_act_K))/gama+(KT_Al2PO4*(S_act_Al*S_act_Al)*3.0)/gama3-(KT_Na2PO4*(S_act_Na*S_act_Na))/gama-(KT_HPO4*S_act_H*2.0)/gama2-(KT_KPO4*S_act_K*2.0)/gama2-(KT_CaPO4*S_act_Ca)/gama-(KT_NaPO4*S_act_Na*2.0)/gama2-(KT_MgPO4*S_act_Mg)/gama-(KT_KHPO4*S_act_H*S_act_K)/gama+(KT_FeHPO4*S_act_H*S_act_Fe3)/gama+(KT_AlHPO4*S_act_H*S_act_Al)/gama-(KT_NaHPO4*S_act_H*S_act_Na)/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_Ca)/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_Fe2)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_Fe3*2.0)/gama2;


gradEqu[12] =  3.0/gama3+(KT_AlOH*2.0)/(S_act_H*gama2)+(KT_AlOH2*1.0/(S_act_H*S_act_H))/gama-(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H))/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac))/gama-(KT_AlS2O8*(S_act_SO4*S_act_SO4))/gama+(KT_AlAc*S_act_Ac*2.0)/gama2+(KT_AlSO4*S_act_SO4)/gama+(KT_AlCl*S_act_Cl*2.0)/gama2+(KT_AlBu*S_act_Bu*2.0)/gama2+(KT_AlPr*S_act_Pr*2.0)/gama2+(KT_AlHPO4*S_act_H*S_act_PO4)/gama+(KT_Al2PO4*S_act_PO4*S_act_Al*6.0)/gama3+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*S_act_Al*8.0)/gama4+(KT_AlOHAc*S_act_Ac)/(S_act_H*gama)+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*1.5E1)/gama5+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*S_act_Al*4.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al*6.0)/gama3;


gradEqu[13] =  2.0/gama2+KT_FeOH/(S_act_H*gama)-(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H))/gama+(KT_FeHS*S_act_HS)/gama+(KT_FeAc*S_act_Ac)/gama+(KT_FeCl*S_act_Cl)/gama+(KT_FeHCO3*S_act_H*S_act_CO3)/gama+(KT_FeNH3*S_act_NH4*2.0)/(S_act_H*gama2)+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*2.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[14] =  3.0/gama3+(KT_FeOH2*1.0/(S_act_H*S_act_H))/gama-(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H))/gama+(KT_FeOH_2*2.0)/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac))/gama-(KT_FeS2O8*(S_act_SO4*S_act_SO4))/gama+(KT_FeSO4*S_act_SO4)/gama+(KT_FePr*S_act_Pr*2.0)/gama2+(KT_FeAc_2*S_act_Ac*2.0)/gama2+(KT_FeCl_2*S_act_Cl*2.0)/gama2+(KT_FeBu_2*S_act_Bu*2.0)/gama2+(KT_FeVa_2*S_act_Va*2.0)/gama2+(KT_FeHPO4*S_act_H*S_act_PO4)/gama+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*S_act_Fe3*8.0)/gama4+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*2.0)/gama2+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*1.5E1)/gama5;


gradEqu[15] =  -1.0/gama-(KT_S*2.0)/(S_act_H*gama2)+(KT_FeHS*S_act_Fe2)/gama;


gradEqu[16] =  -1.0/gama+(KT_CaBu*S_act_Ca)/gama+(KT_AlBu*S_act_Al*2.0)/gama2+(KT_MgBu*S_act_Mg)/gama+(KT_FeBu_2*S_act_Fe3*2.0)/gama2;


gradEqu[17] =  -1.0/gama+(KT_CaVa*S_act_Ca)/gama+(KT_FeVa_2*S_act_Fe3*2.0)/gama2;


gradEqu[18] =  0.0;


gradEqu[19] =  -S_act_H*1.0/(gama*gama)-S_act_K*1.0/(gama*gama)-S_act_NH4*1.0/(gama*gama)+S_act_HS*1.0/(gama*gama)+S_act_Ac*1.0/(gama*gama)+S_act_Cl*1.0/(gama*gama)-S_act_Na*1.0/(gama*gama)+S_act_Bu*1.0/(gama*gama)+S_act_Va*1.0/(gama*gama)+S_act_Pr*1.0/(gama*gama)+(KT_H2O*1.0/(gama*gama))/S_act_H+KT_HCO3*S_act_H*S_act_CO3*1.0/(gama*gama)+KT_HSO4*S_act_H*S_act_SO4*1.0/(gama*gama)+KT_KSO4*S_act_K*S_act_SO4*1.0/(gama*gama)+KT_NaCO3*S_act_CO3*S_act_Na*1.0/(gama*gama)-KT_FeHS*S_act_HS*S_act_Fe2*1.0/(gama*gama)+KT_CaPO4*S_act_PO4*S_act_Ca*1.0/(gama*gama)-KT_CaAc*S_act_Ac*S_act_Ca*1.0/(gama*gama)-KT_FeAc*S_act_Ac*S_act_Fe2*1.0/(gama*gama)+KT_NH4SO4*S_act_NH4*S_act_SO4*1.0/(gama*gama)-KT_FeSO4*S_act_SO4*S_act_Fe3*1.0/(gama*gama)-KT_CaCl*S_act_Ca*S_act_Cl*1.0/(gama*gama)-KT_AlSO4*S_act_SO4*S_act_Al*1.0/(gama*gama)+KT_NaSO4*S_act_SO4*S_act_Na*1.0/(gama*gama)+KT_MgPO4*S_act_PO4*S_act_Mg*1.0/(gama*gama)-KT_MgAc*S_act_Ac*S_act_Mg*1.0/(gama*gama)-KT_FeCl*S_act_Fe2*S_act_Cl*1.0/(gama*gama)-KT_CaBu*S_act_Ca*S_act_Bu*1.0/(gama*gama)-KT_CaVa*S_act_Ca*S_act_Va*1.0/(gama*gama)-KT_MgCl*S_act_Cl*S_act_Mg*1.0/(gama*gama)-KT_CaPr*S_act_Ca*S_act_Pr*1.0/(gama*gama)-KT_MgBu*S_act_Mg*S_act_Bu*1.0/(gama*gama)-KT_MgPr*S_act_Mg*S_act_Pr*1.0/(gama*gama)+KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4*1.0/(gama*gama)+KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*1.0/(gama*gama)-(KT_CaOH*S_act_Ca*1.0/(gama*gama))/S_act_H-(KT_FeOH*S_act_Fe2*1.0/(gama*gama))/S_act_H-KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)+KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2*1.0/(gama*gama)-KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)+KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)+KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)-(KT_MgOH*S_act_Mg*1.0/(gama*gama))/S_act_H-KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*1.0/(gama*gama)-KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*1.0/(gama*gama)+KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*1.0/(gama*gama)+KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*1.0/(gama*gama)+KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*1.0/(gama*gama)+KT_KHPO4*S_act_H*S_act_K*S_act_PO4*1.0/(gama*gama)-KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca*1.0/(gama*gama)-KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2*1.0/(gama*gama)-KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg*1.0/(gama*gama)-KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3*1.0/(gama*gama)-KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al*1.0/(gama*gama)+KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na*1.0/(gama*gama)-KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca*1.0/(gama*gama)-KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2*1.0/(gama*gama)-(KT_AlOHAc*S_act_Ac*S_act_Al*1.0/(gama*gama))/S_act_H;


// Eq1: Na

gradEqu[20] =  KT_NaHCO3_aq*S_act_CO3*S_act_Na-KT_NaOH_aq*1.0/(S_act_H*S_act_H)*S_act_Na+KT_Na2HPO4_aq*S_act_PO4*(S_act_Na*S_act_Na)*2.0+(KT_NaHPO4*S_act_PO4*S_act_Na)/gama+KT_NaH2PO4_aq*S_act_H*S_act_PO4*S_act_Na*2.0;


gradEqu[21] =  KT_NaOH_aq/S_act_H+1.0/gama+KT_NaAc_aq*S_act_Ac+KT_NaCl_aq*S_act_Cl+KT_NaHCO3_aq*S_act_H*S_act_CO3+KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4+(KT_NaCO3*S_act_CO3)/gama+(KT_NaPO4*S_act_PO4)/gama2+(KT_NaSO4*S_act_SO4)/gama+(KT_NaHPO4*S_act_H*S_act_PO4)/gama+(KT_Na2PO4*S_act_PO4*S_act_Na*4.0)/gama+KT_Na2HPO4_aq*S_act_H*S_act_PO4*S_act_Na*4.0;


gradEqu[22] =  0.0;


gradEqu[23] =  0.0;


gradEqu[24] =  KT_NaCl_aq*S_act_Na;


gradEqu[25] =  KT_NaAc_aq*S_act_Na;


gradEqu[26] =  0.0;


gradEqu[27] =  0.0;


gradEqu[28] =  0.0;


gradEqu[29] =  KT_NaHCO3_aq*S_act_H*S_act_Na+(KT_NaCO3*S_act_Na)/gama;


gradEqu[30] =  (KT_NaSO4*S_act_Na)/gama;


gradEqu[31] = (KT_Na2PO4*(S_act_Na*S_act_Na)*2.0)/gama+KT_Na2HPO4_aq*S_act_H*(S_act_Na*S_act_Na)*2.0+KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_Na+(KT_NaPO4*S_act_Na)/gama2+(KT_NaHPO4*S_act_H*S_act_Na)/gama;


gradEqu[32] =  0.0;


gradEqu[33] =  0.0;


gradEqu[34] =  0.0;


gradEqu[35] =  0.0;


gradEqu[36] =  0.0;


gradEqu[37] =  0.0;


gradEqu[38] =  0.0;


gradEqu[39] =  -S_act_Na*1.0/(gama*gama)-KT_NaCO3*S_act_CO3*S_act_Na*1.0/(gama*gama)-KT_NaSO4*S_act_SO4*S_act_Na*1.0/(gama*gama)-KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*1.0/(gama*gama)*2.0-KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na*1.0/(gama*gama);


// Eq2: K

gradEqu[40] =  -KT_KOH_aq*1.0/(S_act_H*S_act_H)*S_act_K+KT_K2HPO4_aq*(S_act_K*S_act_K)*S_act_PO4*2.0+(KT_KHPO4*S_act_K*S_act_PO4)/gama+KT_KH2PO4_aq*S_act_H*S_act_K*S_act_PO4*2.0;


gradEqu[41] =  0.0;


gradEqu[42] =  KT_KOH_aq/S_act_H+1.0/gama+KT_KAc_aq*S_act_Ac+KT_KCl_aq*S_act_Cl+KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4+(KT_KPO4*S_act_PO4)/gama2+(KT_KSO4*S_act_SO4)/gama+(KT_K2PO4*S_act_K*S_act_PO4*4.0)/gama+(KT_KHPO4*S_act_H*S_act_PO4)/gama+KT_K2HPO4_aq*S_act_H*S_act_K*S_act_PO4*4.0;


gradEqu[43] =  0.0;


gradEqu[44] =  KT_KCl_aq*S_act_K;


gradEqu[45] =  KT_KAc_aq*S_act_K;


gradEqu[46] =  0.0;


gradEqu[47] =  0.0;


gradEqu[48] =  0.0;


gradEqu[49] =  0.0;


gradEqu[50] =  (KT_KSO4*S_act_K)/gama;


gradEqu[51] =  (KT_K2PO4*(S_act_K*S_act_K)*2.0)/gama+KT_K2HPO4_aq*S_act_H*(S_act_K*S_act_K)*2.0+KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_K+(KT_KPO4*S_act_K)/gama2+(KT_KHPO4*S_act_H*S_act_K)/gama;


gradEqu[52] =  0.0;


gradEqu[53] =  0.0;


gradEqu[54] =  0.0;


gradEqu[55] =  0.0;


gradEqu[56] =  0.0;


gradEqu[57] =  0.0;


gradEqu[58] =  0.0;


gradEqu[59] =  -S_act_K*1.0/(gama*gama)-KT_KSO4*S_act_K*S_act_SO4*1.0/(gama*gama)-KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*1.0/(gama*gama)*2.0-KT_KHPO4*S_act_H*S_act_K*S_act_PO4*1.0/(gama*gama);

// Eq4 : NH4

gradEqu[60] =  -KT_NH3_aq*1.0/(S_act_H*S_act_H)*S_act_NH4-(KT_CaN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*4.0)/gama2-(KT_FeN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2-(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*9.0)/gama2-(KT_MgN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*4.0)/gama2-(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*1.6E1)/gama2-(KT_CaNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca)/gama2-(KT_FeNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2)/gama2;


gradEqu[61] =  0.0;


gradEqu[62] =  0.0;


gradEqu[63] =  KT_NH3_aq/S_act_H+1.0/gama+(KT_NH4SO4*S_act_SO4)/gama+(KT_CaNH3*S_act_Ca)/(S_act_H*gama2)+(KT_FeNH3*S_act_Fe2)/(S_act_H*gama2)+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*9.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*1.6E1)/gama2+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*4.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Mg*4.0)/gama2;


gradEqu[64] = 0.0;


gradEqu[65] =  0.0;


gradEqu[66] =  0.0;


gradEqu[67] =  (KT_CaNH3*S_act_NH4)/(S_act_H*gama2)+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[68] = (KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[69] =  0.0;


gradEqu[70] =  (KT_NH4SO4*S_act_NH4)/gama;


gradEqu[71] =  0.0;


gradEqu[72] =  0.0;


gradEqu[73] =  (KT_FeNH3*S_act_NH4)/(S_act_H*gama2)+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*3.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*4.0)/gama2;


gradEqu[74] =  0.0;


gradEqu[75] =  0.0;


gradEqu[76] =  0.0;


gradEqu[77] =  0.0;


gradEqu[78] =  0.0;


gradEqu[79] =  -S_act_NH4*1.0/(gama*gama)-KT_NH4SO4*S_act_NH4*S_act_SO4*1.0/(gama*gama);

// Eq 5: Cl


gradEqu[80] =  0.0;


gradEqu[81] = KT_NaCl_aq*S_act_Cl;


gradEqu[82] =  KT_KCl_aq*S_act_Cl;


gradEqu[83] = 0.0;


gradEqu[84] = 1.0/gama+KT_KCl_aq*S_act_K+KT_NaCl_aq*S_act_Na+(KT_CaCl*S_act_Ca)/gama+(KT_FeCl*S_act_Fe2)/gama+(KT_AlCl*S_act_Al)/gama2+(KT_MgCl*S_act_Mg)/gama+(KT_FeCl_2*S_act_Fe3)/gama2;


gradEqu[85] =  0.0;


gradEqu[86] =  0.0;


gradEqu[87] =  (KT_CaCl*S_act_Cl)/gama;


gradEqu[88] =  (KT_MgCl*S_act_Cl)/gama;


gradEqu[89] =  0.0;


gradEqu[90] =  0.0;


gradEqu[91] =  0.0;


gradEqu[92] =  (KT_AlCl*S_act_Cl)/gama2;


gradEqu[93] =  (KT_FeCl*S_act_Cl)/gama;


gradEqu[94] =  (KT_FeCl_2*S_act_Cl)/gama2;


gradEqu[95] =  0.0;


gradEqu[96] =  0.0;


gradEqu[97] =  0.0;


gradEqu[98] =  0.0;


gradEqu[99] =  -S_act_Cl*1.0/(gama*gama)-KT_CaCl*S_act_Ca*S_act_Cl*1.0/(gama*gama)-KT_FeCl*S_act_Fe2*S_act_Cl*1.0/(gama*gama)-KT_MgCl*S_act_Cl*S_act_Mg*1.0/(gama*gama);

// Eq 6 : Ac

gradEqu[100] =  KT_HAc_aq*S_act_Ac-(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*2.0)/gama3-(KT_AlOHAc*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al)/gama;


gradEqu[101] =  KT_NaAc_aq*S_act_Ac;


gradEqu[102] =  KT_KAc_aq*S_act_Ac;


gradEqu[103] =  0.0;


gradEqu[104] =  0.0;


gradEqu[105] =  1.0/gama+KT_HAc_aq*S_act_H+KT_KAc_aq*S_act_K+KT_NaAc_aq*S_act_Na+KT_FeAc3_aq*(S_act_Ac*S_act_Ac)*S_act_Fe3*9.0+(KT_CaAc*S_act_Ca)/gama+(KT_FeAc*S_act_Fe2)/gama+(KT_AlAc*S_act_Al)/gama2+(KT_MgAc*S_act_Mg)/gama+(KT_FeAc_2*S_act_Fe3)/gama2+(KT_FeAc2*S_act_Ac*S_act_Fe3*4.0)/gama+(KT_AlAc2*S_act_Ac*S_act_Al*4.0)/gama+(KT_AlOHAc*S_act_Al)/(S_act_H*gama)+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al))/gama3;


gradEqu[106] =  0.0;


gradEqu[107] =  (KT_CaAc*S_act_Ac)/gama;


gradEqu[108] =  (KT_MgAc*S_act_Ac)/gama;


gradEqu[109] =  0.0;


gradEqu[110] =  0.0;


gradEqu[111] =  0.0;


gradEqu[112] =  (KT_AlAc2*(S_act_Ac*S_act_Ac)*2.0)/gama+(KT_AlAc*S_act_Ac)/gama2+(KT_AlOHAc*S_act_Ac)/(S_act_H*gama)+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al*2.0)/gama3;


gradEqu[113] =  (KT_FeAc*S_act_Ac)/gama;


gradEqu[114] =  KT_FeAc3_aq*(S_act_Ac*S_act_Ac*S_act_Ac)*3.0+(KT_FeAc2*(S_act_Ac*S_act_Ac)*2.0)/gama+(KT_FeAc_2*S_act_Ac)/gama2;


gradEqu[115] =  0.0;


gradEqu[116] =  0.0;


gradEqu[117] =  0.0;


gradEqu[118] =  0.0;


gradEqu[119] =  -S_act_Ac*1.0/(gama*gama)-KT_CaAc*S_act_Ac*S_act_Ca*1.0/(gama*gama)-KT_FeAc*S_act_Ac*S_act_Fe2*1.0/(gama*gama)-KT_MgAc*S_act_Ac*S_act_Mg*1.0/(gama*gama)-KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*1.0/(gama*gama)*2.0-KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*1.0/(gama*gama)*2.0-(KT_AlOHAc*S_act_Ac*S_act_Al*1.0/(gama*gama))/S_act_H;

// Eq7 : Pro

gradEqu[120] =  KT_HPr_aq*S_act_Pr;


gradEqu[121] =  0.0;


gradEqu[122] =  0.0;


gradEqu[123] =  0.0;


gradEqu[124] =  0.0;


gradEqu[125] =  0.0;


gradEqu[126] =  1.0/gama+KT_HPr_aq*S_act_H+(KT_CaPr*S_act_Ca)/gama+(KT_FePr*S_act_Fe3)/gama2+(KT_AlPr*S_act_Al)/gama2+(KT_MgPr*S_act_Mg)/gama;


gradEqu[127] =  (KT_CaPr*S_act_Pr)/gama;


gradEqu[128] =  (KT_MgPr*S_act_Pr)/gama;


gradEqu[129] =  0.0;


gradEqu[130] =  0.0;


gradEqu[131] =  0.0;


gradEqu[132] =  (KT_AlPr*S_act_Pr)/gama2;


gradEqu[133] =  0.0;


gradEqu[134] =  (KT_FePr*S_act_Pr)/gama2;


gradEqu[135] =  0.0;


gradEqu[136] =  0.0;


gradEqu[137] =  0.0;


gradEqu[138] =  0.0;


gradEqu[139] =  -S_act_Pr*1.0/(gama*gama)-KT_CaPr*S_act_Ca*S_act_Pr*1.0/(gama*gama)-KT_MgPr*S_act_Mg*S_act_Pr*1.0/(gama*gama);

// Eq8: Ca

gradEqu[140] =  KT_CaHPO4_aq*S_act_PO4*S_act_Ca+(KT_CaHCO3*S_act_CO3*S_act_Ca)/gama-(KT_CaOH*1.0/(S_act_H*S_act_H)*S_act_Ca)/gama-(KT_CaN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*2.0)/gama2+(KT_CaH2PO4*S_act_H*S_act_PO4*S_act_Ca*2.0)/gama-(KT_CaNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca)/gama2;


gradEqu[141] =  0.0;


gradEqu[142] =  0.0;


gradEqu[143] = (KT_CaNH3*S_act_Ca)/(S_act_H*gama2)+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*2.0)/gama2;


gradEqu[144] = (KT_CaCl*S_act_Ca)/gama;


gradEqu[145] =  (KT_CaAc*S_act_Ca)/gama;


gradEqu[146] =  (KT_CaPr*S_act_Ca)/gama;


gradEqu[147] =  1.0/gama2+KT_CaCO3_aq*S_act_CO3+KT_CaSO4_aq*S_act_SO4+KT_CaOH/(S_act_H*gama)+KT_CaHPO4_aq*S_act_H*S_act_PO4+(KT_CaPO4*S_act_PO4)/gama+(KT_CaAc*S_act_Ac)/gama+(KT_CaCl*S_act_Cl)/gama+(KT_CaBu*S_act_Bu)/gama+(KT_CaVa*S_act_Va)/gama+(KT_CaPr*S_act_Pr)/gama+(KT_CaHCO3*S_act_H*S_act_CO3)/gama+(KT_CaNH3*S_act_NH4)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4))/gama2;


gradEqu[148] =  0.0;


gradEqu[149] =  KT_CaCO3_aq*S_act_Ca+(KT_CaHCO3*S_act_H*S_act_Ca)/gama;


gradEqu[150] =  KT_CaSO4_aq*S_act_Ca;


gradEqu[151] =  KT_CaHPO4_aq*S_act_H*S_act_Ca+(KT_CaPO4*S_act_Ca)/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_Ca)/gama;


gradEqu[152] =  0.0;


gradEqu[153] =  0.0;


gradEqu[154] =  0.0;


gradEqu[155] =  0.0;


gradEqu[156] =  (KT_CaBu*S_act_Ca)/gama;


gradEqu[157] =  (KT_CaVa*S_act_Ca)/gama;


gradEqu[158] =  0.0;


gradEqu[159] =  -KT_CaPO4*S_act_PO4*S_act_Ca*1.0/(gama*gama)-KT_CaAc*S_act_Ac*S_act_Ca*1.0/(gama*gama)-KT_CaCl*S_act_Ca*S_act_Cl*1.0/(gama*gama)-KT_CaBu*S_act_Ca*S_act_Bu*1.0/(gama*gama)-KT_CaVa*S_act_Ca*S_act_Va*1.0/(gama*gama)-KT_CaPr*S_act_Ca*S_act_Pr*1.0/(gama*gama)-(KT_CaOH*S_act_Ca*1.0/(gama*gama))/S_act_H-KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca*1.0/(gama*gama)-KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca*1.0/(gama*gama);


// Eq9: Mg

gradEqu[160] =  KT_MgHPO4_aq*S_act_PO4*S_act_Mg+(KT_MgHCO3*S_act_CO3*S_act_Mg)/gama-(KT_MgOH*1.0/(S_act_H*S_act_H)*S_act_Mg)/gama-(KT_MgN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*2.0)/gama2;


gradEqu[161] =  0.0;


gradEqu[162] =  0.0;


gradEqu[163] =  (KT_MgN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Mg*2.0)/gama2;


gradEqu[164] =  (KT_MgCl*S_act_Mg)/gama;


gradEqu[165] =  (KT_MgAc*S_act_Mg)/gama;


gradEqu[166] =  (KT_MgPr*S_act_Mg)/gama;


gradEqu[167] =  0.0;


gradEqu[168] =  1.0/gama2+KT_MgCO3_aq*S_act_CO3+KT_MgSO4_aq*S_act_SO4+KT_MgOH/(S_act_H*gama)+KT_MgHPO4_aq*S_act_H*S_act_PO4+(KT_MgPO4*S_act_PO4)/gama+(KT_MgAc*S_act_Ac)/gama+(KT_MgCl*S_act_Cl)/gama+(KT_MgBu*S_act_Bu)/gama+(KT_MgPr*S_act_Pr)/gama+(KT_MgHCO3*S_act_H*S_act_CO3)/gama+(KT_Mg2CO3*S_act_CO3*S_act_Mg*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4))/gama2;


gradEqu[169] =  KT_MgCO3_aq*S_act_Mg+(KT_Mg2CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2+(KT_MgHCO3*S_act_H*S_act_Mg)/gama;


gradEqu[170] =  KT_MgSO4_aq*S_act_Mg;


gradEqu[171] =  KT_MgHPO4_aq*S_act_H*S_act_Mg+(KT_MgPO4*S_act_Mg)/gama;


gradEqu[172] =  0.0;


gradEqu[173] =  0.0;


gradEqu[174] =  0.0;


gradEqu[175] =  0.0;


gradEqu[176] =  (KT_MgBu*S_act_Mg)/gama;


gradEqu[177] =  0.0;


gradEqu[178] =  0.0;


gradEqu[179] =  -KT_MgPO4*S_act_PO4*S_act_Mg*1.0/(gama*gama)-KT_MgAc*S_act_Ac*S_act_Mg*1.0/(gama*gama)-KT_MgCl*S_act_Cl*S_act_Mg*1.0/(gama*gama)-KT_MgBu*S_act_Mg*S_act_Bu*1.0/(gama*gama)-KT_MgPr*S_act_Mg*S_act_Pr*1.0/(gama*gama)-(KT_MgOH*S_act_Mg*1.0/(gama*gama))/S_act_H-KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg*1.0/(gama*gama);

// Eq10: CO3-2

gradEqu[180] =  KT_CO2*S_act_H*S_act_CO3*2.0+KT_H2CO3_aq*S_act_H*S_act_CO3*2.0+KT_NaHCO3_aq*S_act_CO3*S_act_Na+(KT_HCO3*S_act_CO3)/gama+(KT_CaHCO3*S_act_CO3*S_act_Ca)/gama+(KT_FeHCO3*S_act_CO3*S_act_Fe2)/gama+(KT_MgHCO3*S_act_CO3*S_act_Mg)/gama-(KT_AlOH2CO3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*2.0)/gama2;


gradEqu[181] =  KT_NaHCO3_aq*S_act_H*S_act_CO3+(KT_NaCO3*S_act_CO3)/gama;


gradEqu[182] =  0.0;


gradEqu[183] =  0.0;


gradEqu[184] =  0.0;


gradEqu[185] =  0.0;


gradEqu[186] =  0.0;


gradEqu[187] =  KT_CaCO3_aq*S_act_CO3+(KT_CaHCO3*S_act_H*S_act_CO3)/gama;


gradEqu[188] =  KT_MgCO3_aq*S_act_CO3+(KT_MgHCO3*S_act_H*S_act_CO3)/gama+(KT_Mg2CO3*S_act_CO3*S_act_Mg*2.0)/gama2;


gradEqu[189] =  KT_CO2*(S_act_H*S_act_H)+KT_H2CO3_aq*(S_act_H*S_act_H)+1.0/gama2+KT_CaCO3_aq*S_act_Ca+KT_MgCO3_aq*S_act_Mg+(KT_Mg2CO3*(S_act_Mg*S_act_Mg))/gama2+KT_NaHCO3_aq*S_act_H*S_act_Na+(KT_HCO3*S_act_H)/gama+(KT_NaCO3*S_act_Na)/gama+(KT_CaHCO3*S_act_H*S_act_Ca)/gama+(KT_FeHCO3*S_act_H*S_act_Fe2)/gama+(KT_MgHCO3*S_act_H*S_act_Mg)/gama+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al))/gama2;


gradEqu[190] =  0.0;


gradEqu[191] =  0.0;


gradEqu[192] =  (KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*S_act_Al*2.0)/gama2;


gradEqu[193] =  (KT_FeHCO3*S_act_H*S_act_CO3)/gama;


gradEqu[194] =  0.0;


gradEqu[195] =  0.0;


gradEqu[196] =  0.0;


gradEqu[197] =  0.0;


gradEqu[198] =  0.0;


gradEqu[199] =  -KT_HCO3*S_act_H*S_act_CO3*1.0/(gama*gama)-KT_NaCO3*S_act_CO3*S_act_Na*1.0/(gama*gama)-KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca*1.0/(gama*gama)-KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2*1.0/(gama*gama)-KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg*1.0/(gama*gama);

// Eq11: SO4

gradEqu[200] =  (KT_HSO4*S_act_SO4)/gama;


gradEqu[201] =  (KT_NaSO4*S_act_SO4)/gama;


gradEqu[202] =  (KT_KSO4*S_act_SO4)/gama;


gradEqu[203] = (KT_NH4SO4*S_act_SO4)/gama;


gradEqu[204] =  0.0;


gradEqu[205] =  0.0;


gradEqu[206] =  0.0;


gradEqu[207] =  KT_CaSO4_aq*S_act_SO4;


gradEqu[208] =  KT_MgSO4_aq*S_act_SO4;


gradEqu[209] =  0.0;


gradEqu[210] =  1.0/gama2+KT_CaSO4_aq*S_act_Ca+KT_FeSO4_aq*S_act_Fe2+KT_MgSO4_aq*S_act_Mg+(KT_HSO4*S_act_H)/gama+(KT_KSO4*S_act_K)/gama+(KT_NH4SO4*S_act_NH4)/gama+(KT_FeSO4*S_act_Fe3)/gama+(KT_AlSO4*S_act_Al)/gama+(KT_NaSO4*S_act_Na)/gama+(KT_FeS2O8*S_act_SO4*S_act_Fe3*4.0)/gama+(KT_AlS2O8*S_act_SO4*S_act_Al*4.0)/gama;


gradEqu[211] =  0.0;


gradEqu[212] = (KT_AlS2O8*(S_act_SO4*S_act_SO4)*2.0)/gama+(KT_AlSO4*S_act_SO4)/gama;


gradEqu[213] =  KT_FeSO4_aq*S_act_SO4;


gradEqu[214] =  (KT_FeS2O8*(S_act_SO4*S_act_SO4)*2.0)/gama+(KT_FeSO4*S_act_SO4)/gama;


gradEqu[215] =  0.0;


gradEqu[216] =  0.0;


gradEqu[217] =  0.0;


gradEqu[218] =  0.0;


gradEqu[219] =  -KT_HSO4*S_act_H*S_act_SO4*1.0/(gama*gama)-KT_KSO4*S_act_K*S_act_SO4*1.0/(gama*gama)-KT_NH4SO4*S_act_NH4*S_act_SO4*1.0/(gama*gama)-KT_FeSO4*S_act_SO4*S_act_Fe3*1.0/(gama*gama)-KT_AlSO4*S_act_SO4*S_act_Al*1.0/(gama*gama)-KT_NaSO4*S_act_SO4*S_act_Na*1.0/(gama*gama)-KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*1.0/(gama*gama)*2.0-KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*1.0/(gama*gama)*2.0;

// Eq12: PO4-3

gradEqu[220] =  KT_CaHPO4_aq*S_act_PO4*S_act_Ca+KT_FeHPO4_aq*S_act_PO4*S_act_Fe2+KT_MgHPO4_aq*S_act_PO4*S_act_Mg+KT_H3PO4*(S_act_H*S_act_H)*S_act_PO4*3.0+KT_K2HPO4_aq*(S_act_K*S_act_K)*S_act_PO4+KT_Na2HPO4_aq*S_act_PO4*(S_act_Na*S_act_Na)+(KT_HPO4*S_act_PO4)/gama2+(KT_H2PO4*S_act_H*S_act_PO4*2.0)/gama+(KT_KHPO4*S_act_K*S_act_PO4)/gama+(KT_FeHPO4*S_act_PO4*S_act_Fe3)/gama+(KT_AlHPO4*S_act_PO4*S_act_Al)/gama+(KT_NaHPO4*S_act_PO4*S_act_Na)/gama+KT_KH2PO4_aq*S_act_H*S_act_K*S_act_PO4*2.0+KT_NaH2PO4_aq*S_act_H*S_act_PO4*S_act_Na*2.0+(KT_CaH2PO4*S_act_H*S_act_PO4*S_act_Ca*2.0)/gama+(KT_FeH2PO4*S_act_H*S_act_PO4*S_act_Fe2*2.0)/gama+(KT_FeH2PO4_2*S_act_H*S_act_PO4*S_act_Fe3*2.0)/gama2;


gradEqu[221] =  KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4+(KT_NaPO4*S_act_PO4)/gama2+(KT_NaHPO4*S_act_H*S_act_PO4)/gama+(KT_Na2PO4*S_act_PO4*S_act_Na*2.0)/gama+KT_Na2HPO4_aq*S_act_H*S_act_PO4*S_act_Na*2.0;


gradEqu[222] =  KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_PO4+(KT_KPO4*S_act_PO4)/gama2+(KT_K2PO4*S_act_K*S_act_PO4*2.0)/gama+(KT_KHPO4*S_act_H*S_act_PO4)/gama+KT_K2HPO4_aq*S_act_H*S_act_K*S_act_PO4*2.0;


gradEqu[223] =  0.0;


gradEqu[224] =  0.0;


gradEqu[225] =  0.0;


gradEqu[226] = 0.0;


gradEqu[227] =  KT_CaHPO4_aq*S_act_H*S_act_PO4+(KT_CaPO4*S_act_PO4)/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama;


gradEqu[228] =  KT_MgHPO4_aq*S_act_H*S_act_PO4+(KT_MgPO4*S_act_PO4)/gama;


gradEqu[229] =  0.0;


gradEqu[230] =  0.0;


gradEqu[231] = KT_H3PO4*(S_act_H*S_act_H*S_act_H)+1.0/gama3+(KT_H2PO4*(S_act_H*S_act_H))/gama+(KT_K2PO4*(S_act_K*S_act_K))/gama+(KT_Al2PO4*(S_act_Al*S_act_Al))/gama3+(KT_Na2PO4*(S_act_Na*S_act_Na))/gama+KT_CaHPO4_aq*S_act_H*S_act_Ca+KT_FeHPO4_aq*S_act_H*S_act_Fe2+KT_MgHPO4_aq*S_act_H*S_act_Mg+KT_K2HPO4_aq*S_act_H*(S_act_K*S_act_K)+KT_KH2PO4_aq*(S_act_H*S_act_H)*S_act_K+KT_Na2HPO4_aq*S_act_H*(S_act_Na*S_act_Na)+KT_NaH2PO4_aq*(S_act_H*S_act_H)*S_act_Na+(KT_HPO4*S_act_H)/gama2+(KT_KPO4*S_act_K)/gama2+(KT_CaPO4*S_act_Ca)/gama+(KT_NaPO4*S_act_Na)/gama2+(KT_MgPO4*S_act_Mg)/gama+(KT_KHPO4*S_act_H*S_act_K)/gama+(KT_FeHPO4*S_act_H*S_act_Fe3)/gama+(KT_AlHPO4*S_act_H*S_act_Al)/gama+(KT_NaHPO4*S_act_H*S_act_Na)/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_Ca)/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_Fe2)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_Fe3)/gama2;


gradEqu[232] =  (KT_AlHPO4*S_act_H*S_act_PO4)/gama+(KT_Al2PO4*S_act_PO4*S_act_Al*2.0)/gama3;


gradEqu[233] =  KT_FeHPO4_aq*S_act_H*S_act_PO4+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama;


gradEqu[234] =  (KT_FeHPO4*S_act_H*S_act_PO4)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4)/gama2;


gradEqu[235] =  0.0;


gradEqu[236] =  0.0;


gradEqu[237]  =  0.0;


gradEqu[238] =  0.0;


gradEqu[239] =  -KT_CaPO4*S_act_PO4*S_act_Ca*1.0/(gama*gama)-KT_MgPO4*S_act_PO4*S_act_Mg*1.0/(gama*gama)-KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4*1.0/(gama*gama)-KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*1.0/(gama*gama)-KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*1.0/(gama*gama)-KT_KHPO4*S_act_H*S_act_K*S_act_PO4*1.0/(gama*gama)-KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3*1.0/(gama*gama)-KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al*1.0/(gama*gama)-KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na*1.0/(gama*gama)-KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca*1.0/(gama*gama)-KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2*1.0/(gama*gama);

// Eq13: Al

gradEqu[240] =  KT_AlOH3_aq*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*-3.0+(KT_AlHPO4*S_act_PO4*S_act_Al)/gama-(KT_AlOH*1.0/(S_act_H*S_act_H)*S_act_Al)/gama2-(KT_AlOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Al*2.0)/gama-(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*4.0)/gama-(KT_Al2OH8*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*4.0)/gama4-(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*1.2E1)/gama5-(KT_AlOH2CO3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*4.0)/gama2-(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*4.0)/gama3-(KT_AlOHAc*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al)/gama;


gradEqu[241] =  0.0;


gradEqu[242] =  0.0;


gradEqu[243] =  0.0;


gradEqu[244] =  (KT_AlCl*S_act_Al)/gama2;


gradEqu[245] =  (KT_AlAc*S_act_Al)/gama2+(KT_AlAc2*S_act_Ac*S_act_Al*2.0)/gama+(KT_AlOHAc*S_act_Al)/(S_act_H*gama)+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*2.0)/gama3;


gradEqu[246] =  (KT_AlPr*S_act_Al)/gama2;


gradEqu[247] =  0.0;


gradEqu[248] =  0.0;


gradEqu[249] = (KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*2.0)/gama2;


gradEqu[250] =  (KT_AlSO4*S_act_Al)/gama+(KT_AlS2O8*S_act_SO4*S_act_Al*2.0)/gama;


gradEqu[251] =  (KT_Al2PO4*(S_act_Al*S_act_Al)*2.0)/gama3+(KT_AlHPO4*S_act_H*S_act_Al)/gama;


gradEqu[252] =  KT_AlOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)+1.0/gama3+KT_AlOH/(S_act_H*gama2)+(KT_AlOH2*1.0/(S_act_H*S_act_H))/gama+(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H))/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac))/gama+(KT_AlS2O8*(S_act_SO4*S_act_SO4))/gama+(KT_AlAc*S_act_Ac)/gama2+(KT_AlSO4*S_act_SO4)/gama+(KT_AlCl*S_act_Cl)/gama2+(KT_AlBu*S_act_Bu)/gama2+(KT_AlPr*S_act_Pr)/gama2+(KT_AlHPO4*S_act_H*S_act_PO4)/gama+(KT_Al2PO4*S_act_PO4*S_act_Al*4.0)/gama3+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*S_act_Al*4.0)/gama4+(KT_AlOHAc*S_act_Ac)/(S_act_H*gama)+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*9.0)/gama5+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*S_act_Al*4.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al*4.0)/gama3;


gradEqu[253] =  0.0;


gradEqu[254] =  0.0;


gradEqu[255] =  0.0;


gradEqu[256] =  (KT_AlBu*S_act_Al)/gama2;


gradEqu[257] =  0.0;


gradEqu[258] =  0.0;


gradEqu[259] =  -KT_AlSO4*S_act_SO4*S_act_Al*1.0/(gama*gama)-KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)-KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)-KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*1.0/(gama*gama)-KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*1.0/(gama*gama)-KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al*1.0/(gama*gama)-(KT_AlOHAc*S_act_Ac*S_act_Al*1.0/(gama*gama))/S_act_H;

// Eq14: Fe+2

gradEqu[260] =  KT_FeHPO4_aq*S_act_PO4*S_act_Fe2-KT_FeOH2_aq*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2*2.0+(KT_FeHCO3*S_act_CO3*S_act_Fe2)/gama-(KT_FeOH*1.0/(S_act_H*S_act_H)*S_act_Fe2)/gama-(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe2*3.0)/gama-(KT_FeN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*2.0)/gama2-(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*3.0)/gama2-(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2+(KT_FeH2PO4*S_act_H*S_act_PO4*S_act_Fe2*2.0)/gama-(KT_FeNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2)/gama2;


gradEqu[261] =  0.0;


gradEqu[262] =  0.0;


gradEqu[263] =  (KT_FeNH3*S_act_Fe2)/(S_act_H*gama2)+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*3.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*2.0)/gama2;


gradEqu[264] =  (KT_FeCl*S_act_Fe2)/gama;


gradEqu[265] =  (KT_FeAc*S_act_Fe2)/gama;


gradEqu[266] =  0.0;


gradEqu[267] =  0.0;


gradEqu[268] =  0.0;


gradEqu[269] =  (KT_FeHCO3*S_act_H*S_act_Fe2)/gama;


gradEqu[270] =  KT_FeSO4_aq*S_act_Fe2;


gradEqu[271] =  KT_FeHPO4_aq*S_act_H*S_act_Fe2+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_Fe2)/gama;


gradEqu[272] =  0.0;


gradEqu[273] =  KT_FeOH2_aq*1.0/(S_act_H*S_act_H)+1.0/gama2+KT_FeSO4_aq*S_act_SO4+KT_FeOH/(S_act_H*gama)+(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H))/gama+KT_FeHPO4_aq*S_act_H*S_act_PO4+(KT_FeHS*S_act_HS)/gama+(KT_FeAc*S_act_Ac)/gama+(KT_FeCl*S_act_Cl)/gama+(KT_FeHCO3*S_act_H*S_act_CO3)/gama+(KT_FeNH3*S_act_NH4)/(S_act_H*gama2)+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4)/gama+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4))/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4))/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4))/gama2;


gradEqu[274] =  0.0;


gradEqu[275] =  (KT_FeHS*S_act_Fe2)/gama;


gradEqu[276] =  0.0;


gradEqu[277] =  0.0;


gradEqu[278] =  0.0;


gradEqu[279] =  -KT_FeHS*S_act_HS*S_act_Fe2*1.0/(gama*gama)-KT_FeAc*S_act_Ac*S_act_Fe2*1.0/(gama*gama)-KT_FeCl*S_act_Fe2*S_act_Cl*1.0/(gama*gama)-(KT_FeOH*S_act_Fe2*1.0/(gama*gama))/S_act_H-KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2*1.0/(gama*gama)-KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2*1.0/(gama*gama)-KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2*1.0/(gama*gama);

// Eq14: Fe+3

gradEqu[280] =  KT_FeOH3_aq*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*-3.0+(KT_FeHPO4*S_act_PO4*S_act_Fe3)/gama-(KT_FeOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe3*2.0)/gama-(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*4.0)/gama-(KT_FeOH_2*1.0/(S_act_H*S_act_H)*S_act_Fe3)/gama2-(KT_Fe2O2H2*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*4.0)/gama4-(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*1.2E1)/gama5+(KT_FeH2PO4_2*S_act_H*S_act_PO4*S_act_Fe3*2.0)/gama2;


gradEqu[281] =  0.0;


gradEqu[282] =  0.0;


gradEqu[283] =  0.0;


gradEqu[284] =  (KT_FeCl_2*S_act_Fe3)/gama2;


gradEqu[285] =  KT_FeAc3_aq*(S_act_Ac*S_act_Ac)*S_act_Fe3*3.0+(KT_FeAc_2*S_act_Fe3)/gama2+(KT_FeAc2*S_act_Ac*S_act_Fe3*2.0)/gama;


gradEqu[286] =  (KT_FePr*S_act_Fe3)/gama2;


gradEqu[287] =  0.0;


gradEqu[288] =  0.0;


gradEqu[289] =  0.0;


gradEqu[290] =  (KT_FeSO4*S_act_Fe3)/gama+(KT_FeS2O8*S_act_SO4*S_act_Fe3*2.0)/gama;


gradEqu[291] =  (KT_FeHPO4*S_act_H*S_act_Fe3)/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_Fe3)/gama2;


gradEqu[292] =  0.0;


gradEqu[293] =  0.0;


gradEqu[294] =  KT_FeOH3_aq*1.0/(S_act_H*S_act_H*S_act_H)+KT_FeAc3_aq*(S_act_Ac*S_act_Ac*S_act_Ac)+1.0/gama3+(KT_FeOH2*1.0/(S_act_H*S_act_H))/gama+(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H))/gama+KT_FeOH_2/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac))/gama+(KT_FeS2O8*(S_act_SO4*S_act_SO4))/gama+(KT_FeSO4*S_act_SO4)/gama+(KT_FePr*S_act_Pr)/gama2+(KT_FeAc_2*S_act_Ac)/gama2+(KT_FeCl_2*S_act_Cl)/gama2+(KT_FeBu_2*S_act_Bu)/gama2+(KT_FeVa_2*S_act_Va)/gama2+(KT_FeHPO4*S_act_H*S_act_PO4)/gama+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*S_act_Fe3*4.0)/gama4+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4)/gama2+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*9.0)/gama5;


gradEqu[295] =  0.0;


gradEqu[296] =  (KT_FeBu_2*S_act_Fe3)/gama2;


gradEqu[297] =  (KT_FeVa_2*S_act_Fe3)/gama2;


gradEqu[298] =  0.0;


gradEqu[299] =  -KT_FeSO4*S_act_SO4*S_act_Fe3*1.0/(gama*gama)-KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)-KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)-KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*1.0/(gama*gama)-KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*1.0/(gama*gama)-KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3*1.0/(gama*gama);

// Eq16: HS

gradEqu[300] =  KT_H2S_aq*S_act_HS-(KT_S*1.0/(S_act_H*S_act_H)*S_act_HS)/gama2;


gradEqu[301] =  0.0;


gradEqu[302] =  0.0;


gradEqu[303] =  0.0;


gradEqu[304] =  0.0;


gradEqu[305] =  0.0;


gradEqu[306] =  0.0;


gradEqu[307] =  0.0;


gradEqu[308] =  0.0;


gradEqu[309] =  0.0;


gradEqu[310] =  0.0;


gradEqu[311] =  0.0;


gradEqu[312] =  0.0;


gradEqu[313] =  (KT_FeHS*S_act_HS)/gama;


gradEqu[314] =  0.0;


gradEqu[315] =  1.0/gama+KT_H2S_aq*S_act_H+KT_S/(S_act_H*gama2)+(KT_FeHS*S_act_Fe2)/gama;


gradEqu[316] =  0.0;


gradEqu[317] =  0.0;


gradEqu[318] =  0.0;


gradEqu[319] =  -S_act_HS*1.0/(gama*gama)-KT_FeHS*S_act_HS*S_act_Fe2*1.0/(gama*gama);

// Eq17 : Bu


gradEqu[320] =  KT_HBu_aq*S_act_Bu;


gradEqu[321] =  0.0;


gradEqu[322] =  0.0;


gradEqu[323] =  0.0;


gradEqu[324] =  0.0;


gradEqu[325] =  0.0;


gradEqu[326] =  0.0;


gradEqu[327] =  (KT_CaBu*S_act_Bu)/gama;


gradEqu[328] =  (KT_MgBu*S_act_Bu)/gama;


gradEqu[329] =  0.0;


gradEqu[330] =  0.0;


gradEqu[331] =  0.0;


gradEqu[332] =  (KT_AlBu*S_act_Bu)/gama2;


gradEqu[333] =  0.0;


gradEqu[334] =  (KT_FeBu_2*S_act_Bu)/gama2;


gradEqu[335] =  0.0;


gradEqu[336] =  1.0/gama+KT_HBu_aq*S_act_H+(KT_CaBu*S_act_Ca)/gama+(KT_AlBu*S_act_Al)/gama2+(KT_MgBu*S_act_Mg)/gama+(KT_FeBu_2*S_act_Fe3)/gama2;


gradEqu[337] =  0.0;


gradEqu[338] =  0.0;


gradEqu[339] =  -S_act_Bu*1.0/(gama*gama)-KT_CaBu*S_act_Ca*S_act_Bu*1.0/(gama*gama)-KT_MgBu*S_act_Mg*S_act_Bu*1.0/(gama*gama);

// Eq18: Va


gradEqu[340] =  KT_HVa_aq*S_act_Va;


gradEqu[341] =  0.0;


gradEqu[342] =  0.0;


gradEqu[343] =  0.0;


gradEqu[344] =  0.0;


gradEqu[345] =  0.0;


gradEqu[346] =  0.0;


gradEqu[347] =  (KT_CaVa*S_act_Va)/gama;


gradEqu[348] =  0.0;


gradEqu[349] =  0.0;


gradEqu[350] =  0.0;


gradEqu[351] =  0.0;


gradEqu[352] =  0.0;


gradEqu[353] =  0.0;


gradEqu[354] =  (KT_FeVa_2*S_act_Va)/gama2;


gradEqu[355] =  0.0;


gradEqu[356] =  0.0;


gradEqu[357] =  1.0/gama+KT_HVa_aq*S_act_H+(KT_CaVa*S_act_Ca)/gama+(KT_FeVa_2*S_act_Fe3)/gama2;


gradEqu[358] =  0.0;


gradEqu[359] =  -S_act_Va*1.0/(gama*gama)-KT_CaVa*S_act_Ca*S_act_Va*1.0/(gama*gama);

// Eq19: mu


gradEqu[360] =  (1.0/2.0)/gama-(KT_H2O*1.0/(S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_HCO3*S_act_CO3*(1.0/2.0))/gama+(KT_HPO4*S_act_PO4*2.0)/gama2+(KT_HSO4*S_act_SO4*(1.0/2.0))/gama+(KT_H2PO4*S_act_H*S_act_PO4)/gama+(KT_KHPO4*S_act_K*S_act_PO4*(1.0/2.0))/gama+(KT_CaHCO3*S_act_CO3*S_act_Ca*(1.0/2.0))/gama+(KT_FeHCO3*S_act_CO3*S_act_Fe2*(1.0/2.0))/gama+(KT_MgHCO3*S_act_CO3*S_act_Mg*(1.0/2.0))/gama+(KT_FeHPO4*S_act_PO4*S_act_Fe3*(1.0/2.0))/gama+(KT_AlHPO4*S_act_PO4*S_act_Al*(1.0/2.0))/gama+(KT_NaHPO4*S_act_PO4*S_act_Na*(1.0/2.0))/gama-(KT_S*1.0/(S_act_H*S_act_H)*S_act_HS*2.0)/gama2-(KT_CaOH*1.0/(S_act_H*S_act_H)*S_act_Ca*(1.0/2.0))/gama-(KT_FeOH*1.0/(S_act_H*S_act_H)*S_act_Fe2*(1.0/2.0))/gama-(KT_AlOH*1.0/(S_act_H*S_act_H)*S_act_Al*2.0)/gama2-(KT_FeOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe3)/gama-(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe2*(3.0/2.0))/gama-(KT_AlOH2*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Al)/gama-(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*2.0)/gama-(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*2.0)/gama-(KT_MgOH*1.0/(S_act_H*S_act_H)*S_act_Mg*(1.0/2.0))/gama-(KT_FeOH_2*1.0/(S_act_H*S_act_H)*S_act_Fe3*2.0)/gama2-(KT_Al2OH8*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*1.6E1)/gama4-(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al*S_act_Al)*5.0E1)/gama5-(KT_Fe2O2H2*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*1.6E1)/gama4-(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3*S_act_Fe3)*5.0E1)/gama5-(KT_CaN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Ca*4.0)/gama2-(KT_FeN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*4.0)/gama2-(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*6.0)/gama2-(KT_MgN2H6*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Mg*4.0)/gama2-(KT_AlOH2CO3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_CO3*(S_act_Al*S_act_Al)*4.0)/gama2-(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Ac*(S_act_Al*S_act_Al)*9.0)/gama3-(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*8.0)/gama2+(KT_CaH2PO4*S_act_H*S_act_PO4*S_act_Ca)/gama+(KT_FeH2PO4*S_act_H*S_act_PO4*S_act_Fe2)/gama+(KT_FeH2PO4_2*S_act_H*S_act_PO4*S_act_Fe3*4.0)/gama2-(KT_CaNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*2.0)/gama2-(KT_FeNH3*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*2.0)/gama2-(KT_AlOHAc*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al*(1.0/2.0))/gama;


gradEqu[361] =  (1.0/2.0)/gama+(KT_NaCO3*S_act_CO3*(1.0/2.0))/gama+(KT_NaPO4*S_act_PO4*2.0)/gama2+(KT_NaSO4*S_act_SO4*(1.0/2.0))/gama+(KT_NaHPO4*S_act_H*S_act_PO4*(1.0/2.0))/gama+(KT_Na2PO4*S_act_PO4*S_act_Na)/gama;


gradEqu[362] =  (1.0/2.0)/gama+(KT_KPO4*S_act_PO4*2.0)/gama2+(KT_KSO4*S_act_SO4*(1.0/2.0))/gama+(KT_K2PO4*S_act_K*S_act_PO4)/gama+(KT_KHPO4*S_act_H*S_act_PO4*(1.0/2.0))/gama;


gradEqu[363] =  (1.0/2.0)/gama+(KT_NH4SO4*S_act_SO4*(1.0/2.0))/gama+(KT_CaNH3*S_act_Ca*2.0)/(S_act_H*gama2)+(KT_FeNH3*S_act_Fe2*2.0)/(S_act_H*gama2)+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*S_act_Fe2*6.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*S_act_Fe2*8.0)/gama2+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Ca*4.0)/gama2+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Fe2*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*S_act_NH4*S_act_Mg*4.0)/gama2;


gradEqu[364] =  (1.0/2.0)/gama+(KT_CaCl*S_act_Ca*(1.0/2.0))/gama+(KT_FeCl*S_act_Fe2*(1.0/2.0))/gama+(KT_AlCl*S_act_Al*2.0)/gama2+(KT_MgCl*S_act_Mg*(1.0/2.0))/gama+(KT_FeCl_2*S_act_Fe3*2.0)/gama2;


gradEqu[365] =  (1.0/2.0)/gama+(KT_CaAc*S_act_Ca*(1.0/2.0))/gama+(KT_FeAc*S_act_Fe2*(1.0/2.0))/gama+(KT_AlAc*S_act_Al*2.0)/gama2+(KT_MgAc*S_act_Mg*(1.0/2.0))/gama+(KT_FeAc_2*S_act_Fe3*2.0)/gama2+(KT_FeAc2*S_act_Ac*S_act_Fe3)/gama+(KT_AlAc2*S_act_Ac*S_act_Al)/gama+(KT_AlOHAc*S_act_Al*(1.0/2.0))/(S_act_H*gama)+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*(9.0/2.0))/gama3;


gradEqu[366] =  (1.0/2.0)/gama+(KT_CaPr*S_act_Ca*(1.0/2.0))/gama+(KT_FePr*S_act_Fe3*2.0)/gama2+(KT_AlPr*S_act_Al*2.0)/gama2+(KT_MgPr*S_act_Mg*(1.0/2.0))/gama;


gradEqu[367] =  2.0/gama2+(KT_CaOH*(1.0/2.0))/(S_act_H*gama)+(KT_CaPO4*S_act_PO4*(1.0/2.0))/gama+(KT_CaAc*S_act_Ac*(1.0/2.0))/gama+(KT_CaCl*S_act_Cl*(1.0/2.0))/gama+(KT_CaBu*S_act_Bu*(1.0/2.0))/gama+(KT_CaVa*S_act_Va*(1.0/2.0))/gama+(KT_CaPr*S_act_Pr*(1.0/2.0))/gama+(KT_CaHCO3*S_act_H*S_act_CO3*(1.0/2.0))/gama+(KT_CaNH3*S_act_NH4*2.0)/(S_act_H*gama2)+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*(1.0/2.0))/gama+(KT_CaN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[368] =  2.0/gama2+(KT_MgOH*(1.0/2.0))/(S_act_H*gama)+(KT_MgPO4*S_act_PO4*(1.0/2.0))/gama+(KT_MgAc*S_act_Ac*(1.0/2.0))/gama+(KT_MgCl*S_act_Cl*(1.0/2.0))/gama+(KT_MgBu*S_act_Bu*(1.0/2.0))/gama+(KT_MgPr*S_act_Pr*(1.0/2.0))/gama+(KT_MgHCO3*S_act_H*S_act_CO3*(1.0/2.0))/gama+(KT_Mg2CO3*S_act_CO3*S_act_Mg*4.0)/gama2+(KT_MgN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[369] =  2.0/gama2+(KT_Mg2CO3*(S_act_Mg*S_act_Mg)*2.0)/gama2+(KT_HCO3*S_act_H*(1.0/2.0))/gama+(KT_NaCO3*S_act_Na*(1.0/2.0))/gama+(KT_CaHCO3*S_act_H*S_act_Ca*(1.0/2.0))/gama+(KT_FeHCO3*S_act_H*S_act_Fe2*(1.0/2.0))/gama+(KT_MgHCO3*S_act_H*S_act_Mg*(1.0/2.0))/gama+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*(S_act_Al*S_act_Al)*2.0)/gama2;


gradEqu[370] =  2.0/gama2+(KT_HSO4*S_act_H*(1.0/2.0))/gama+(KT_KSO4*S_act_K*(1.0/2.0))/gama+(KT_NH4SO4*S_act_NH4*(1.0/2.0))/gama+(KT_FeSO4*S_act_Fe3*(1.0/2.0))/gama+(KT_AlSO4*S_act_Al)/gama+(KT_NaSO4*S_act_Na*(1.0/2.0))/gama+(KT_FeS2O8*S_act_SO4*S_act_Fe3)/gama+(KT_AlS2O8*S_act_SO4*S_act_Al)/gama;


gradEqu[371] =  (9.0/2.0)/gama3+(KT_H2PO4*(S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_K2PO4*(S_act_K*S_act_K)*(1.0/2.0))/gama+(KT_Al2PO4*(S_act_Al*S_act_Al)*(9.0/2.0))/gama3+(KT_Na2PO4*(S_act_Na*S_act_Na)*(1.0/2.0))/gama+(KT_HPO4*S_act_H*2.0)/gama2+(KT_KPO4*S_act_K*2.0)/gama2+(KT_CaPO4*S_act_Ca*(1.0/2.0))/gama+(KT_NaPO4*S_act_Na*2.0)/gama2+(KT_MgPO4*S_act_Mg*(1.0/2.0))/gama+(KT_KHPO4*S_act_H*S_act_K*(1.0/2.0))/gama+(KT_FeHPO4*S_act_H*S_act_Fe3*(1.0/2.0))/gama+(KT_AlHPO4*S_act_H*S_act_Al*(1.0/2.0))/gama+(KT_NaHPO4*S_act_H*S_act_Na*(1.0/2.0))/gama+(KT_CaH2PO4*(S_act_H*S_act_H)*S_act_Ca*(1.0/2.0))/gama+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_Fe2*(1.0/2.0))/gama+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_Fe3*2.0)/gama2;


gradEqu[372] =  (9.0/2.0)/gama3+(KT_AlOH*2.0)/(S_act_H*gama2)+(KT_AlOH2*1.0/(S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_AlAc2*(S_act_Ac*S_act_Ac)*(1.0/2.0))/gama+(KT_AlS2O8*(S_act_SO4*S_act_SO4)*(1.0/2.0))/gama+(KT_AlAc*S_act_Ac*2.0)/gama2+(KT_AlSO4*S_act_SO4)/gama+(KT_AlCl*S_act_Cl*2.0)/gama2+(KT_AlBu*S_act_Bu*2.0)/gama2+(KT_AlPr*S_act_Pr*2.0)/gama2+(KT_AlHPO4*S_act_H*S_act_PO4*(1.0/2.0))/gama+(KT_Al2PO4*S_act_PO4*S_act_Al*9.0)/gama3+(KT_Al2OH8*1.0/(S_act_H*S_act_H)*S_act_Al*1.6E1)/gama4+(KT_AlOHAc*S_act_Ac*(1.0/2.0))/(S_act_H*gama)+(KT_Al3OH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Al*S_act_Al)*(7.5E1/2.0))/gama5+(KT_AlOH2CO3*1.0/(S_act_H*S_act_H)*S_act_CO3*S_act_Al*4.0)/gama2+(KT_Al2OH2Ac*1.0/(S_act_H*S_act_H)*S_act_Ac*S_act_Al*9.0)/gama3;


gradEqu[373] =  2.0/gama2+(KT_FeOH*(1.0/2.0))/(S_act_H*gama)+(KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_FeHS*S_act_HS*(1.0/2.0))/gama+(KT_FeAc*S_act_Ac*(1.0/2.0))/gama+(KT_FeCl*S_act_Cl*(1.0/2.0))/gama+(KT_FeHCO3*S_act_H*S_act_CO3*(1.0/2.0))/gama+(KT_FeNH3*S_act_NH4*2.0)/(S_act_H*gama2)+(KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*(1.0/2.0))/gama+(KT_FeN2H6*1.0/(S_act_H*S_act_H)*(S_act_NH4*S_act_NH4)*2.0)/gama2+(KT_FeN3H9*1.0/(S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4)*2.0)/gama2+(KT_FeN4H12*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_NH4*S_act_NH4*S_act_NH4*S_act_NH4)*2.0)/gama2;


gradEqu[374] =  (9.0/2.0)/gama3+(KT_FeOH2*1.0/(S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(1.0/2.0))/gama+(KT_FeOH_2*2.0)/(S_act_H*gama2)+(KT_FeAc2*(S_act_Ac*S_act_Ac)*(1.0/2.0))/gama+(KT_FeS2O8*(S_act_SO4*S_act_SO4)*(1.0/2.0))/gama+(KT_FeSO4*S_act_SO4*(1.0/2.0))/gama+(KT_FePr*S_act_Pr*2.0)/gama2+(KT_FeAc_2*S_act_Ac*2.0)/gama2+(KT_FeCl_2*S_act_Cl*2.0)/gama2+(KT_FeBu_2*S_act_Bu*2.0)/gama2+(KT_FeVa_2*S_act_Va*2.0)/gama2+(KT_FeHPO4*S_act_H*S_act_PO4*(1.0/2.0))/gama+(KT_Fe2O2H2*1.0/(S_act_H*S_act_H)*S_act_Fe3*1.6E1)/gama4+(KT_FeH2PO4_2*(S_act_H*S_act_H)*S_act_PO4*2.0)/gama2+(KT_Fe3O4H4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*(S_act_Fe3*S_act_Fe3)*(7.5E1/2.0))/gama5;


gradEqu[375] =  (1.0/2.0)/gama+(KT_S*2.0)/(S_act_H*gama2)+(KT_FeHS*S_act_Fe2*(1.0/2.0))/gama;


gradEqu[376] =  (1.0/2.0)/gama+(KT_CaBu*S_act_Ca*(1.0/2.0))/gama+(KT_AlBu*S_act_Al*2.0)/gama2+(KT_MgBu*S_act_Mg*(1.0/2.0))/gama+(KT_FeBu_2*S_act_Fe3*2.0)/gama2;


gradEqu[377] =  (1.0/2.0)/gama+(KT_CaVa*S_act_Ca*(1.0/2.0))/gama+(KT_FeVa_2*S_act_Fe3*2.0)/gama2;


gradEqu[378] =  -1.0;


gradEqu[379] =  S_act_H*1.0/(gama*gama)*(-1.0/2.0)-S_act_K*1.0/(gama*gama)*(1.0/2.0)-S_act_NH4*1.0/(gama*gama)*(1.0/2.0)-S_act_HS*1.0/(gama*gama)*(1.0/2.0)-S_act_Ac*1.0/(gama*gama)*(1.0/2.0)-S_act_Cl*1.0/(gama*gama)*(1.0/2.0)-S_act_Na*1.0/(gama*gama)*(1.0/2.0)-S_act_Bu*1.0/(gama*gama)*(1.0/2.0)-S_act_Va*1.0/(gama*gama)*(1.0/2.0)-S_act_Pr*1.0/(gama*gama)*(1.0/2.0)-(KT_H2O*1.0/(gama*gama)*(1.0/2.0))/S_act_H-KT_HCO3*S_act_H*S_act_CO3*1.0/(gama*gama)*(1.0/2.0)-KT_HSO4*S_act_H*S_act_SO4*1.0/(gama*gama)*(1.0/2.0)-KT_KSO4*S_act_K*S_act_SO4*1.0/(gama*gama)*(1.0/2.0)-KT_NaCO3*S_act_CO3*S_act_Na*1.0/(gama*gama)*(1.0/2.0)-KT_FeHS*S_act_HS*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0)-KT_CaPO4*S_act_PO4*S_act_Ca*1.0/(gama*gama)*(1.0/2.0)-KT_CaAc*S_act_Ac*S_act_Ca*1.0/(gama*gama)*(1.0/2.0)-KT_FeAc*S_act_Ac*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0)-KT_NH4SO4*S_act_NH4*S_act_SO4*1.0/(gama*gama)*(1.0/2.0)-KT_FeSO4*S_act_SO4*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_CaCl*S_act_Ca*S_act_Cl*1.0/(gama*gama)*(1.0/2.0)-KT_AlSO4*S_act_SO4*S_act_Al*1.0/(gama*gama)-KT_NaSO4*S_act_SO4*S_act_Na*1.0/(gama*gama)*(1.0/2.0)-KT_MgPO4*S_act_PO4*S_act_Mg*1.0/(gama*gama)*(1.0/2.0)-KT_MgAc*S_act_Ac*S_act_Mg*1.0/(gama*gama)*(1.0/2.0)-KT_FeCl*S_act_Fe2*S_act_Cl*1.0/(gama*gama)*(1.0/2.0)-KT_CaBu*S_act_Ca*S_act_Bu*1.0/(gama*gama)*(1.0/2.0)-KT_CaVa*S_act_Ca*S_act_Va*1.0/(gama*gama)*(1.0/2.0)-KT_MgCl*S_act_Cl*S_act_Mg*1.0/(gama*gama)*(1.0/2.0)-KT_CaPr*S_act_Ca*S_act_Pr*1.0/(gama*gama)*(1.0/2.0)-KT_MgBu*S_act_Mg*S_act_Bu*1.0/(gama*gama)*(1.0/2.0)-KT_MgPr*S_act_Mg*S_act_Pr*1.0/(gama*gama)*(1.0/2.0)-KT_H2PO4*(S_act_H*S_act_H)*S_act_PO4*1.0/(gama*gama)*(1.0/2.0)-KT_K2PO4*(S_act_K*S_act_K)*S_act_PO4*1.0/(gama*gama)*(1.0/2.0)-(KT_CaOH*S_act_Ca*1.0/(gama*gama)*(1.0/2.0))/S_act_H-(KT_FeOH*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0))/S_act_H-KT_FeOH2*1.0/(S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_FeOH3*1.0/(S_act_H*S_act_H*S_act_H)*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0)-KT_AlOH2*1.0/(S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)*(1.0/2.0)-KT_FeOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_AlOH4*1.0/(S_act_H*S_act_H*S_act_H*S_act_H)*S_act_Al*1.0/(gama*gama)*(1.0/2.0)-(KT_MgOH*S_act_Mg*1.0/(gama*gama)*(1.0/2.0))/S_act_H-KT_FeAc2*(S_act_Ac*S_act_Ac)*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_AlAc2*(S_act_Ac*S_act_Ac)*S_act_Al*1.0/(gama*gama)*(1.0/2.0)-KT_Na2PO4*S_act_PO4*(S_act_Na*S_act_Na)*1.0/(gama*gama)*(1.0/2.0)-KT_FeS2O8*(S_act_SO4*S_act_SO4)*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_AlS2O8*(S_act_SO4*S_act_SO4)*S_act_Al*1.0/(gama*gama)*(1.0/2.0)-KT_KHPO4*S_act_H*S_act_K*S_act_PO4*1.0/(gama*gama)*(1.0/2.0)-KT_CaHCO3*S_act_H*S_act_CO3*S_act_Ca*1.0/(gama*gama)*(1.0/2.0)-KT_FeHCO3*S_act_H*S_act_CO3*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0)-KT_MgHCO3*S_act_H*S_act_CO3*S_act_Mg*1.0/(gama*gama)*(1.0/2.0)-KT_FeHPO4*S_act_H*S_act_PO4*S_act_Fe3*1.0/(gama*gama)*(1.0/2.0)-KT_AlHPO4*S_act_H*S_act_PO4*S_act_Al*1.0/(gama*gama)*(1.0/2.0)-KT_NaHPO4*S_act_H*S_act_PO4*S_act_Na*1.0/(gama*gama)*(1.0/2.0)-KT_CaH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Ca*1.0/(gama*gama)*(1.0/2.0)-KT_FeH2PO4*(S_act_H*S_act_H)*S_act_PO4*S_act_Fe2*1.0/(gama*gama)*(1.0/2.0)-(KT_AlOHAc*S_act_Ac*S_act_Al*1.0/(gama*gama)*(1.0/2.0))/S_act_H;

// Eq20: gama


gradEqu[380] =  0.0;


gradEqu[381] =  0.0;


gradEqu[382] =  0.0;


gradEqu[383] =  0.0;


gradEqu[384] =  0.0;


gradEqu[385] =  0.0;


gradEqu[386] =  0.0;


gradEqu[387] =  0.0;


gradEqu[388] =  0.0;


gradEqu[389] =  0.0;


gradEqu[390] =  0.0;


gradEqu[391] =  0.0;


gradEqu[392] =  0.0;


gradEqu[393] =  0.0;


gradEqu[394] =  0.0;


gradEqu[395] =  0.0;


gradEqu[396] =  0.0;


gradEqu[397] =  0.0;


gradEqu[398] =  pow(1.0E1,A*(mu*(3.0/1.0E1)-sqrt(mu)/(sqrt(mu)+1.0)))*A*log(1.0E1)*(1.0/pow(sqrt(mu)+1.0,2.0)*(1.0/2.0)-(1.0/sqrt(mu)*(1.0/2.0))/(sqrt(mu)+1.0)+3.0/1.0E1);


gradEqu[399] =  -1.0;

	for (i=0;i<20;i++){
		for (j=0;j<20;j++){
			jac[20*i+j]=gradEqu[i+20*j];//transpose
		}
	}
	return status;
}

// bool JacNum(const double x[], double *jac)
// {
// 	double xnew[8], gresold[8], gres[8];
// 	unsigned int i, j;
// 	bool status;
// 	//calculate base case
// 	status=FunEv(x,8,gresold);
// 	//Perturb by line
// 	for (i=0;i<8;i++){  //outer loop, x
// 		//calculate new x
// 		for (j = 0; j < 8; j++) xnew[j]=x[j];
// 		//perturb x[i]
// 		xnew[i]+=xnew[i]*1e-6;
// 		//calculate new gres
// 		status=FunEv(xnew,8,gres);
// 		//place in jac
// 		for (j=0;j<8;j++){
// 			jac[8*j+i]=(gres[j]-gresold[j])/(xnew[i]-x[i]);//by columns need to correct NAN
// 		}
// 	}
// 	//initial jac estimate
// 	return status;
// }

/*
 * mdlUpdate - perform action at major integration time step
 */
static void mdlUpdate(double *x, double *u, SimStruct *S, int tid)
{
	double kk;
	double Equ, gradEqu;
	/*need to fix with malloc*/ 
	double gres[20], gresold[20], jac[400], jaca[400], jacdelta[400], xold[20], xnew[20], xtemp[20], deltax[20];//, testmat[100],testvec[10],testout[10];
	double acc[20], wt[20];
	double delta, startvalue;
	double TOL;
	unsigned int MaxSteps;
	bool status, conv;
	int i,j;

	TOL = 1e-5;
	MaxSteps= 1000;
	j=1;
//	wt[0]=0.8;wt[1]=0.8;wt[2]=0.8;wt[3]=0.8;wt[4]=1;wt[5]=0.8;wt[6]=0.8;wt[7]=0.8;
	//This is function root position
	//set globals so subfunctions can use them
	Smain=S;
	umain=u; 
	//transfer x & tol
	for (i = 0; i < 20; i++)xnew[i]=x[i];
	for (i = 0; i < 20; i++) acc[i]=TOL;
	status=FunEv(xnew,20,gres);
	conv=1;
	for (i=0;i<20;i++) if (fabs(gres[i])>acc[i]) conv=0;
	j=0;
	//main loop
	while ((!conv) && (j <= MaxSteps)){
	//Calculate the Jacobian
		//status=JacNum(xnew,&jac);
		status=JacAna(xnew,&jaca);
	//Calculate residual
		status=FunEv(xnew,20,gres);
	//Calculate deltax
		MatDiv(20, &jaca, &gres, &deltax);
		//for(i=0;i<64;i++)jacdelta[i]=(jaca[i]-jac[i])/jaca[i];

		/*for (i=0;i<8;i++) {
			if (fabs(jaca[9*i]) <= 1e-20) deltax[i]=0.0;
			else deltax[i]=gres[i]/jaca[9*i]*wt[i]; //try it with an eigenjacobian
		}*/ 

	//Update x and store old values
		for (i = 0; i < 20; i++){
			xold[i]=xnew[i];
			gresold[i]=gres[i];
			xnew[i]=xold[i]-deltax[i];//weighting should be changed.
		}
		
		conv=1;
		for (i=0;i<20;i++) {
			if (fabs(gres[i])>acc[i]) conv=0;
		}

	}
	if (conv)
	{
		for (i = 0; i < 20; i++) x[i]=xnew[i];
	}
	else status=0;
}





/*
 * mdlDerivatives - compute the derivatives
 */
static void mdlDerivatives(double *dx, double *x, double *u, SimStruct *S, int tid)
{
}


/*
 * mdlTerminate - called when the simulation is terminated.
 */
static void mdlTerminate(SimStruct *S)
{
}

#ifdef	MATLAB_MEX_FILE    /* Is this file being compiled as a MEX-file? */
#include "simulink.c"      /* MEX-file interface mechanism */
#else
#include "cg_sfun.h"       /* Code generation registration function */
#endif
